/*
 * Copyright (C) 2010-2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/EnumTraits.h>

namespace IPC {

enum class ReceiverName : uint8_t {
    GPUConnectionToWebProcess = 1
    , GPUProcess = 2
    , RemoteRenderingBackendProxy = 3
    , RemoteAudioDestinationManager = 4
    , RemoteAudioSessionProxy = 5
    , RemoteCDMFactoryProxy = 6
    , RemoteCDMInstanceProxy = 7
    , RemoteCDMInstanceSessionProxy = 8
    , RemoteCDMProxy = 9
    , RemoteLegacyCDMFactoryProxy = 10
    , RemoteLegacyCDMProxy = 11
    , RemoteLegacyCDMSessionProxy = 12
    , RemoteMediaPlayerManagerProxy = 13
    , RemoteMediaPlayerProxy = 14
    , RemoteMediaResourceManager = 15
    , LibWebRTCCodecsProxy = 16
    , RemoteAudioMediaStreamTrackRenderer = 17
    , RemoteAudioMediaStreamTrackRendererManager = 18
    , RemoteMediaRecorder = 19
    , RemoteMediaRecorderManager = 20
    , RemoteSampleBufferDisplayLayer = 21
    , RemoteSampleBufferDisplayLayerManager = 22
    , WebCookieManager = 23
    , WebIDBServer = 24
    , NetworkConnectionToWebProcess = 25
    , NetworkContentRuleListManager = 26
    , NetworkProcess = 27
    , NetworkResourceLoader = 28
    , NetworkSocketChannel = 29
    , NetworkSocketStream = 30
    , ServiceWorkerFetchTask = 31
    , WebSWServerConnection = 32
    , WebSWServerToContextConnection = 33
    , StorageManagerSet = 34
    , CacheStorageEngineConnection = 35
    , NetworkMDNSRegister = 36
    , NetworkRTCMonitor = 37
    , NetworkRTCProvider = 38
    , NetworkRTCSocket = 39
    , PluginControllerProxy = 40
    , PluginProcess = 41
    , WebProcessConnection = 42
    , AuxiliaryProcess = 43
    , WebConnection = 44
    , AuthenticationManager = 45
    , NPObjectMessageReceiver = 46
    , DrawingAreaProxy = 47
    , VisitedLinkStore = 48
    , WebCookieManagerProxy = 49
    , WebFullScreenManagerProxy = 50
    , WebGeolocationManagerProxy = 51
    , WebPageProxy = 52
    , WebPasteboardProxy = 53
    , WebProcessPool = 54
    , WebProcessProxy = 55
    , WebAutomationSession = 56
    , DownloadProxy = 57
    , GPUProcessProxy = 58
    , RemoteWebInspectorProxy = 59
    , WebInspectorProxy = 60
    , NetworkProcessProxy = 61
    , PluginProcessProxy = 62
    , WebUserContentControllerProxy = 63
    , WebProcess = 64
    , WebAutomationSessionProxy = 65
    , WebIDBConnectionToServer = 66
    , WebFullScreenManager = 67
    , GPUProcessConnection = 68
    , RemoteRenderingBackend = 69
    , MediaPlayerPrivateRemote = 70
    , RemoteAudioDestinationProxy = 71
    , RemoteAudioSession = 72
    , RemoteCDMInstanceSession = 73
    , RemoteLegacyCDMSession = 74
    , RemoteMediaPlayerManager = 75
    , LibWebRTCCodecs = 76
    , SampleBufferDisplayLayer = 77
    , WebGeolocationManager = 78
    , RemoteWebInspectorUI = 79
    , WebInspector = 80
    , WebInspectorInterruptDispatcher = 81
    , WebInspectorUI = 82
    , LibWebRTCNetwork = 83
    , WebMDNSRegister = 84
    , WebRTCMonitor = 85
    , WebRTCResolver = 86
    , NetworkProcessConnection = 87
    , WebResourceLoader = 88
    , WebSocketChannel = 89
    , WebSocketStream = 90
    , WebNotificationManager = 91
    , PluginProcessConnection = 92
    , PluginProcessConnectionManager = 93
    , PluginProxy = 94
    , WebSWClientConnection = 95
    , WebSWContextManagerConnection = 96
    , WebUserContentController = 97
    , DrawingArea = 98
    , EventDispatcher = 99
    , VisitedLinkTableController = 100
    , WebPage = 101
    , StorageAreaMap = 102
    , ViewGestureController = 103
    , ViewGestureGeometryCollector = 104
    , IPC = 105
    , AsyncReply = 106
    , Invalid = 107
};

enum class MessageName : uint16_t {
    GPUConnectionToWebProcess_CreateRenderingBackend = 1
    , GPUConnectionToWebProcess_ReleaseRenderingBackend = 2
    , GPUConnectionToWebProcess_ClearNowPlayingInfo = 3
    , GPUConnectionToWebProcess_SetNowPlayingInfo = 4
#if USE(AUDIO_SESSION)
    , GPUConnectionToWebProcess_EnsureAudioSession = 5
#endif
#if PLATFORM(IOS_FAMILY)
    , GPUConnectionToWebProcess_EnsureMediaSessionHelper = 6
#endif
    , GPUProcess_InitializeGPUProcess = 7
    , GPUProcess_CreateGPUConnectionToWebProcess = 8
    , GPUProcess_CreateGPUConnectionToWebProcessReply = 9
    , GPUProcess_ProcessDidTransitionToForeground = 10
    , GPUProcess_ProcessDidTransitionToBackground = 11
    , GPUProcess_AddSession = 12
    , GPUProcess_RemoveSession = 13
#if ENABLE(MEDIA_STREAM)
    , GPUProcess_SetMockCaptureDevicesEnabled = 14
#endif
#if ENABLE(MEDIA_STREAM)
    , GPUProcess_SetOrientationForMediaCapture = 15
#endif
#if ENABLE(MEDIA_STREAM)
    , GPUProcess_UpdateCaptureAccess = 16
    , GPUProcess_UpdateCaptureAccessReply = 17
#endif
    , RemoteRenderingBackendProxy_CreateImageBuffer = 18
    , RemoteRenderingBackendProxy_ReleaseImageBuffer = 19
    , RemoteRenderingBackendProxy_FlushImageBufferDrawingContext = 20
    , RemoteRenderingBackendProxy_FlushImageBufferDrawingContextAndCommit = 21
    , RemoteRenderingBackendProxy_GetImageData = 22
    , RemoteAudioDestinationManager_CreateAudioDestination = 23
    , RemoteAudioDestinationManager_DeleteAudioDestination = 24
    , RemoteAudioDestinationManager_DeleteAudioDestinationReply = 25
    , RemoteAudioDestinationManager_StartAudioDestination = 26
    , RemoteAudioDestinationManager_StopAudioDestination = 27
    , RemoteAudioSessionProxy_SetCategory = 28
    , RemoteAudioSessionProxy_SetPreferredBufferSize = 29
    , RemoteAudioSessionProxy_TryToSetActive = 30
    , RemoteCDMFactoryProxy_CreateCDM = 31
    , RemoteCDMFactoryProxy_SupportsKeySystem = 32
    , RemoteCDMInstanceProxy_CreateSession = 33
    , RemoteCDMInstanceProxy_InitializeWithConfiguration = 34
    , RemoteCDMInstanceProxy_InitializeWithConfigurationReply = 35
    , RemoteCDMInstanceProxy_SetServerCertificate = 36
    , RemoteCDMInstanceProxy_SetServerCertificateReply = 37
    , RemoteCDMInstanceProxy_SetStorageDirectory = 38
    , RemoteCDMInstanceSessionProxy_RequestLicense = 39
    , RemoteCDMInstanceSessionProxy_RequestLicenseReply = 40
    , RemoteCDMInstanceSessionProxy_UpdateLicense = 41
    , RemoteCDMInstanceSessionProxy_UpdateLicenseReply = 42
    , RemoteCDMInstanceSessionProxy_LoadSession = 43
    , RemoteCDMInstanceSessionProxy_LoadSessionReply = 44
    , RemoteCDMInstanceSessionProxy_CloseSession = 45
    , RemoteCDMInstanceSessionProxy_CloseSessionReply = 46
    , RemoteCDMInstanceSessionProxy_RemoveSessionData = 47
    , RemoteCDMInstanceSessionProxy_RemoveSessionDataReply = 48
    , RemoteCDMInstanceSessionProxy_StoreRecordOfKeyUsage = 49
    , RemoteCDMProxy_GetSupportedConfiguration = 50
    , RemoteCDMProxy_GetSupportedConfigurationReply = 51
    , RemoteCDMProxy_CreateInstance = 52
    , RemoteCDMProxy_LoadAndInitialize = 53
    , RemoteLegacyCDMFactoryProxy_CreateCDM = 54
    , RemoteLegacyCDMFactoryProxy_SupportsKeySystem = 55
    , RemoteLegacyCDMProxy_SupportsMIMEType = 56
    , RemoteLegacyCDMProxy_CreateSession = 57
    , RemoteLegacyCDMProxy_SetPlayerId = 58
    , RemoteLegacyCDMSessionProxy_GenerateKeyRequest = 59
    , RemoteLegacyCDMSessionProxy_ReleaseKeys = 60
    , RemoteLegacyCDMSessionProxy_Update = 61
    , RemoteLegacyCDMSessionProxy_CachedKeyForKeyID = 62
    , RemoteMediaPlayerManagerProxy_CreateMediaPlayer = 63
    , RemoteMediaPlayerManagerProxy_CreateMediaPlayerReply = 64
    , RemoteMediaPlayerManagerProxy_DeleteMediaPlayer = 65
    , RemoteMediaPlayerManagerProxy_GetSupportedTypes = 66
    , RemoteMediaPlayerManagerProxy_SupportsTypeAndCodecs = 67
    , RemoteMediaPlayerManagerProxy_CanDecodeExtendedType = 68
    , RemoteMediaPlayerManagerProxy_OriginsInMediaCache = 69
    , RemoteMediaPlayerManagerProxy_ClearMediaCache = 70
    , RemoteMediaPlayerManagerProxy_ClearMediaCacheForOrigins = 71
    , RemoteMediaPlayerManagerProxy_SupportsKeySystem = 72
    , RemoteMediaPlayerProxy_PrepareForPlayback = 73
    , RemoteMediaPlayerProxy_PrepareForPlaybackReply = 74
    , RemoteMediaPlayerProxy_Load = 75
    , RemoteMediaPlayerProxy_LoadReply = 76
    , RemoteMediaPlayerProxy_CancelLoad = 77
    , RemoteMediaPlayerProxy_PrepareToPlay = 78
    , RemoteMediaPlayerProxy_Play = 79
    , RemoteMediaPlayerProxy_Pause = 80
    , RemoteMediaPlayerProxy_SetVolume = 81
    , RemoteMediaPlayerProxy_SetMuted = 82
    , RemoteMediaPlayerProxy_Seek = 83
    , RemoteMediaPlayerProxy_SeekWithTolerance = 84
    , RemoteMediaPlayerProxy_SetPreload = 85
    , RemoteMediaPlayerProxy_SetPrivateBrowsingMode = 86
    , RemoteMediaPlayerProxy_SetPreservesPitch = 87
    , RemoteMediaPlayerProxy_PrepareForRendering = 88
    , RemoteMediaPlayerProxy_SetVisible = 89
    , RemoteMediaPlayerProxy_SetShouldMaintainAspectRatio = 90
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_SetVideoFullscreenGravity = 91
#endif
    , RemoteMediaPlayerProxy_AcceleratedRenderingStateChanged = 92
    , RemoteMediaPlayerProxy_SetShouldDisableSleep = 93
    , RemoteMediaPlayerProxy_SetRate = 94
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_UpdateVideoFullscreenInlineImage = 95
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_SetVideoFullscreenMode = 96
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_VideoFullscreenStandbyChanged = 97
#endif
    , RemoteMediaPlayerProxy_SetBufferingPolicy = 98
    , RemoteMediaPlayerProxy_AudioTrackSetEnabled = 99
    , RemoteMediaPlayerProxy_VideoTrackSetSelected = 100
    , RemoteMediaPlayerProxy_TextTrackSetMode = 101
#if PLATFORM(COCOA)
    , RemoteMediaPlayerProxy_SetVideoInlineSizeFenced = 102
#endif
#if (PLATFORM(COCOA) && ENABLE(VIDEO_PRESENTATION_MODE))
    , RemoteMediaPlayerProxy_SetVideoFullscreenFrameFenced = 103
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_EnterFullscreen = 104
    , RemoteMediaPlayerProxy_EnterFullscreenReply = 105
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_ExitFullscreen = 106
    , RemoteMediaPlayerProxy_ExitFullscreenReply = 107
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    , RemoteMediaPlayerProxy_SetWirelessVideoPlaybackDisabled = 108
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    , RemoteMediaPlayerProxy_SetShouldPlayToPlaybackTarget = 109
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_SetLegacyCDMSession = 110
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_KeyAdded = 111
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_CdmInstanceAttached = 112
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_CdmInstanceDetached = 113
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_AttemptToDecryptWithInstance = 114
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA) && ENABLE(ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_SetShouldContinueAfterKeyNeeded = 115
#endif
    , RemoteMediaPlayerProxy_BeginSimulatedHDCPError = 116
    , RemoteMediaPlayerProxy_EndSimulatedHDCPError = 117
    , RemoteMediaPlayerProxy_NotifyActiveSourceBuffersChanged = 118
    , RemoteMediaPlayerProxy_ApplicationWillResignActive = 119
    , RemoteMediaPlayerProxy_ApplicationDidBecomeActive = 120
    , RemoteMediaPlayerProxy_NotifyTrackModeChanged = 121
    , RemoteMediaPlayerProxy_TracksChanged = 122
    , RemoteMediaPlayerProxy_SyncTextTrackBounds = 123
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    , RemoteMediaPlayerProxy_SetWirelessPlaybackTarget = 124
#endif
    , RemoteMediaPlayerProxy_PerformTaskAtMediaTime = 125
    , RemoteMediaPlayerProxy_PerformTaskAtMediaTimeReply = 126
    , RemoteMediaPlayerProxy_WouldTaintOrigin = 127
#if PLATFORM(IOS_FAMILY)
    , RemoteMediaPlayerProxy_ErrorLog = 128
#endif
#if PLATFORM(IOS_FAMILY)
    , RemoteMediaPlayerProxy_AccessLog = 129
#endif
    , RemoteMediaResourceManager_ResponseReceived = 130
    , RemoteMediaResourceManager_ResponseReceivedReply = 131
    , RemoteMediaResourceManager_RedirectReceived = 132
    , RemoteMediaResourceManager_RedirectReceivedReply = 133
    , RemoteMediaResourceManager_DataSent = 134
    , RemoteMediaResourceManager_DataReceived = 135
    , RemoteMediaResourceManager_AccessControlCheckFailed = 136
    , RemoteMediaResourceManager_LoadFailed = 137
    , RemoteMediaResourceManager_LoadFinished = 138
    , LibWebRTCCodecsProxy_CreateH264Decoder = 139
    , LibWebRTCCodecsProxy_CreateH265Decoder = 140
    , LibWebRTCCodecsProxy_ReleaseDecoder = 141
    , LibWebRTCCodecsProxy_DecodeFrame = 142
    , LibWebRTCCodecsProxy_CreateEncoder = 143
    , LibWebRTCCodecsProxy_ReleaseEncoder = 144
    , LibWebRTCCodecsProxy_InitializeEncoder = 145
    , LibWebRTCCodecsProxy_EncodeFrame = 146
    , LibWebRTCCodecsProxy_SetEncodeRates = 147
    , RemoteAudioMediaStreamTrackRenderer_Start = 148
    , RemoteAudioMediaStreamTrackRenderer_Stop = 149
    , RemoteAudioMediaStreamTrackRenderer_Clear = 150
    , RemoteAudioMediaStreamTrackRenderer_SetVolume = 151
    , RemoteAudioMediaStreamTrackRenderer_AudioSamplesStorageChanged = 152
    , RemoteAudioMediaStreamTrackRenderer_AudioSamplesAvailable = 153
    , RemoteAudioMediaStreamTrackRendererManager_CreateRenderer = 154
    , RemoteAudioMediaStreamTrackRendererManager_ReleaseRenderer = 155
    , RemoteMediaRecorder_AudioSamplesStorageChanged = 156
    , RemoteMediaRecorder_AudioSamplesAvailable = 157
    , RemoteMediaRecorder_VideoSampleAvailable = 158
    , RemoteMediaRecorder_FetchData = 159
    , RemoteMediaRecorder_FetchDataReply = 160
    , RemoteMediaRecorder_StopRecording = 161
    , RemoteMediaRecorderManager_CreateRecorder = 162
    , RemoteMediaRecorderManager_CreateRecorderReply = 163
    , RemoteMediaRecorderManager_ReleaseRecorder = 164
    , RemoteSampleBufferDisplayLayer_UpdateDisplayMode = 165
    , RemoteSampleBufferDisplayLayer_UpdateAffineTransform = 166
    , RemoteSampleBufferDisplayLayer_UpdateBoundsAndPosition = 167
    , RemoteSampleBufferDisplayLayer_Flush = 168
    , RemoteSampleBufferDisplayLayer_FlushAndRemoveImage = 169
    , RemoteSampleBufferDisplayLayer_EnqueueSample = 170
    , RemoteSampleBufferDisplayLayer_ClearEnqueuedSamples = 171
    , RemoteSampleBufferDisplayLayerManager_CreateLayer = 172
    , RemoteSampleBufferDisplayLayerManager_CreateLayerReply = 173
    , RemoteSampleBufferDisplayLayerManager_ReleaseLayer = 174
    , WebCookieManager_GetHostnamesWithCookies = 175
    , WebCookieManager_GetHostnamesWithCookiesReply = 176
    , WebCookieManager_DeleteCookiesForHostnames = 177
    , WebCookieManager_DeleteAllCookies = 178
    , WebCookieManager_SetCookie = 179
    , WebCookieManager_SetCookieReply = 180
    , WebCookieManager_SetCookies = 181
    , WebCookieManager_SetCookiesReply = 182
    , WebCookieManager_GetAllCookies = 183
    , WebCookieManager_GetAllCookiesReply = 184
    , WebCookieManager_GetCookies = 185
    , WebCookieManager_GetCookiesReply = 186
    , WebCookieManager_DeleteCookie = 187
    , WebCookieManager_DeleteCookieReply = 188
    , WebCookieManager_DeleteAllCookiesModifiedSince = 189
    , WebCookieManager_DeleteAllCookiesModifiedSinceReply = 190
    , WebCookieManager_SetHTTPCookieAcceptPolicy = 191
    , WebCookieManager_SetHTTPCookieAcceptPolicyReply = 192
    , WebCookieManager_GetHTTPCookieAcceptPolicy = 193
    , WebCookieManager_GetHTTPCookieAcceptPolicyReply = 194
    , WebCookieManager_StartObservingCookieChanges = 195
    , WebCookieManager_StopObservingCookieChanges = 196
#if USE(SOUP)
    , WebCookieManager_SetCookiePersistentStorage = 197
#endif
    , WebIDBServer_DeleteDatabase = 198
    , WebIDBServer_OpenDatabase = 199
    , WebIDBServer_AbortTransaction = 200
    , WebIDBServer_CommitTransaction = 201
    , WebIDBServer_DidFinishHandlingVersionChangeTransaction = 202
    , WebIDBServer_CreateObjectStore = 203
    , WebIDBServer_DeleteObjectStore = 204
    , WebIDBServer_RenameObjectStore = 205
    , WebIDBServer_ClearObjectStore = 206
    , WebIDBServer_CreateIndex = 207
    , WebIDBServer_DeleteIndex = 208
    , WebIDBServer_RenameIndex = 209
    , WebIDBServer_PutOrAdd = 210
    , WebIDBServer_GetRecord = 211
    , WebIDBServer_GetAllRecords = 212
    , WebIDBServer_GetCount = 213
    , WebIDBServer_DeleteRecord = 214
    , WebIDBServer_OpenCursor = 215
    , WebIDBServer_IterateCursor = 216
    , WebIDBServer_EstablishTransaction = 217
    , WebIDBServer_DatabaseConnectionPendingClose = 218
    , WebIDBServer_DatabaseConnectionClosed = 219
    , WebIDBServer_AbortOpenAndUpgradeNeeded = 220
    , WebIDBServer_DidFireVersionChangeEvent = 221
    , WebIDBServer_OpenDBRequestCancelled = 222
    , WebIDBServer_GetAllDatabaseNames = 223
    , NetworkConnectionToWebProcess_ScheduleResourceLoad = 224
    , NetworkConnectionToWebProcess_PerformSynchronousLoad = 225
    , NetworkConnectionToWebProcess_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply = 226
    , NetworkConnectionToWebProcess_LoadPing = 227
    , NetworkConnectionToWebProcess_RemoveLoadIdentifier = 228
    , NetworkConnectionToWebProcess_PageLoadCompleted = 229
    , NetworkConnectionToWebProcess_BrowsingContextRemoved = 230
    , NetworkConnectionToWebProcess_PrefetchDNS = 231
    , NetworkConnectionToWebProcess_PreconnectTo = 232
    , NetworkConnectionToWebProcess_StartDownload = 233
    , NetworkConnectionToWebProcess_ConvertMainResourceLoadToDownload = 234
    , NetworkConnectionToWebProcess_CookiesForDOM = 235
    , NetworkConnectionToWebProcess_SetCookiesFromDOM = 236
    , NetworkConnectionToWebProcess_CookieRequestHeaderFieldValue = 237
    , NetworkConnectionToWebProcess_GetRawCookies = 238
    , NetworkConnectionToWebProcess_SetRawCookie = 239
    , NetworkConnectionToWebProcess_DeleteCookie = 240
    , NetworkConnectionToWebProcess_DomCookiesForHost = 241
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    , NetworkConnectionToWebProcess_UnsubscribeFromCookieChangeNotifications = 242
#endif
    , NetworkConnectionToWebProcess_RegisterFileBlobURL = 243
    , NetworkConnectionToWebProcess_RegisterBlobURL = 244
    , NetworkConnectionToWebProcess_RegisterBlobURLFromURL = 245
    , NetworkConnectionToWebProcess_RegisterBlobURLOptionallyFileBacked = 246
    , NetworkConnectionToWebProcess_RegisterBlobURLForSlice = 247
    , NetworkConnectionToWebProcess_UnregisterBlobURL = 248
    , NetworkConnectionToWebProcess_BlobSize = 249
    , NetworkConnectionToWebProcess_WriteBlobsToTemporaryFiles = 250
    , NetworkConnectionToWebProcess_WriteBlobsToTemporaryFilesReply = 251
    , NetworkConnectionToWebProcess_SetCaptureExtraNetworkLoadMetricsEnabled = 252
    , NetworkConnectionToWebProcess_CreateSocketStream = 253
    , NetworkConnectionToWebProcess_CreateSocketChannel = 254
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_RemoveStorageAccessForFrame = 255
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_ClearPageSpecificDataForResourceLoadStatistics = 256
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_LogUserInteraction = 257
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_ResourceLoadStatisticsUpdated = 258
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_HasStorageAccess = 259
    , NetworkConnectionToWebProcess_HasStorageAccessReply = 260
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_RequestStorageAccess = 261
    , NetworkConnectionToWebProcess_RequestStorageAccessReply = 262
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_RequestStorageAccessUnderOpener = 263
#endif
    , NetworkConnectionToWebProcess_AddOriginAccessWhitelistEntry = 264
    , NetworkConnectionToWebProcess_RemoveOriginAccessWhitelistEntry = 265
    , NetworkConnectionToWebProcess_ResetOriginAccessWhitelists = 266
    , NetworkConnectionToWebProcess_GetNetworkLoadInformationResponse = 267
    , NetworkConnectionToWebProcess_GetNetworkLoadIntermediateInformation = 268
    , NetworkConnectionToWebProcess_TakeNetworkLoadInformationMetrics = 269
#if ENABLE(SERVICE_WORKER)
    , NetworkConnectionToWebProcess_EstablishSWContextConnection = 270
    , NetworkConnectionToWebProcess_EstablishSWContextConnectionReply = 271
#endif
#if ENABLE(SERVICE_WORKER)
    , NetworkConnectionToWebProcess_CloseSWContextConnection = 272
#endif
    , NetworkConnectionToWebProcess_UpdateQuotaBasedOnSpaceUsageForTesting = 273
    , NetworkConnectionToWebProcess_CreateNewMessagePortChannel = 274
    , NetworkConnectionToWebProcess_EntangleLocalPortInThisProcessToRemote = 275
    , NetworkConnectionToWebProcess_MessagePortDisentangled = 276
    , NetworkConnectionToWebProcess_MessagePortClosed = 277
    , NetworkConnectionToWebProcess_TakeAllMessagesForPort = 278
    , NetworkConnectionToWebProcess_TakeAllMessagesForPortReply = 279
    , NetworkConnectionToWebProcess_PostMessageToRemote = 280
    , NetworkConnectionToWebProcess_CheckRemotePortForActivity = 281
    , NetworkConnectionToWebProcess_CheckRemotePortForActivityReply = 282
    , NetworkConnectionToWebProcess_DidDeliverMessagePortMessages = 283
    , NetworkConnectionToWebProcess_RegisterURLSchemesAsCORSEnabled = 284
    , NetworkContentRuleListManager_Remove = 285
    , NetworkContentRuleListManager_AddContentRuleLists = 286
    , NetworkContentRuleListManager_RemoveContentRuleList = 287
    , NetworkContentRuleListManager_RemoveAllContentRuleLists = 288
    , NetworkProcess_InitializeNetworkProcess = 289
    , NetworkProcess_CreateNetworkConnectionToWebProcess = 290
    , NetworkProcess_CreateNetworkConnectionToWebProcessReply = 291
#if USE(SOUP)
    , NetworkProcess_SetIgnoreTLSErrors = 292
#endif
#if USE(SOUP)
    , NetworkProcess_UserPreferredLanguagesChanged = 293
#endif
#if USE(SOUP)
    , NetworkProcess_SetNetworkProxySettings = 294
#endif
#if USE(SOUP)
    , NetworkProcess_PrefetchDNS = 295
#endif
#if USE(CURL)
    , NetworkProcess_SetNetworkProxySettings = 296
#endif
    , NetworkProcess_ClearCachedCredentials = 297
    , NetworkProcess_AddWebsiteDataStore = 298
    , NetworkProcess_DestroySession = 299
    , NetworkProcess_FetchWebsiteData = 300
    , NetworkProcess_DeleteWebsiteData = 301
    , NetworkProcess_DeleteWebsiteDataForOrigins = 302
    , NetworkProcess_RenameOriginInWebsiteData = 303
    , NetworkProcess_RenameOriginInWebsiteDataReply = 304
    , NetworkProcess_DownloadRequest = 305
    , NetworkProcess_ResumeDownload = 306
    , NetworkProcess_CancelDownload = 307
#if PLATFORM(COCOA)
    , NetworkProcess_PublishDownloadProgress = 308
#endif
    , NetworkProcess_ApplicationDidEnterBackground = 309
    , NetworkProcess_ApplicationWillEnterForeground = 310
    , NetworkProcess_ContinueWillSendRequest = 311
    , NetworkProcess_ContinueDecidePendingDownloadDestination = 312
#if PLATFORM(COCOA)
    , NetworkProcess_SetQOS = 313
#endif
#if PLATFORM(COCOA)
    , NetworkProcess_SetStorageAccessAPIEnabled = 314
#endif
    , NetworkProcess_SetAllowsAnySSLCertificateForWebSocket = 315
    , NetworkProcess_SyncAllCookies = 316
    , NetworkProcess_AllowSpecificHTTPSCertificateForHost = 317
    , NetworkProcess_SetCacheModel = 318
    , NetworkProcess_SetCacheModelSynchronouslyForTesting = 319
    , NetworkProcess_ProcessDidTransitionToBackground = 320
    , NetworkProcess_ProcessDidTransitionToForeground = 321
    , NetworkProcess_ProcessWillSuspendImminentlyForTestingSync = 322
    , NetworkProcess_PrepareToSuspend = 323
    , NetworkProcess_PrepareToSuspendReply = 324
    , NetworkProcess_ProcessDidResume = 325
    , NetworkProcess_PreconnectTo = 326
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ClearPrevalentResource = 327
    , NetworkProcess_ClearPrevalentResourceReply = 328
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ClearUserInteraction = 329
    , NetworkProcess_ClearUserInteractionReply = 330
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_DumpResourceLoadStatistics = 331
    , NetworkProcess_DumpResourceLoadStatisticsReply = 332
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetResourceLoadStatisticsEnabled = 333
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetResourceLoadStatisticsLogTestingEvent = 334
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_UpdatePrevalentDomainsToBlockCookiesFor = 335
    , NetworkProcess_UpdatePrevalentDomainsToBlockCookiesForReply = 336
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsGrandfathered = 337
    , NetworkProcess_IsGrandfatheredReply = 338
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsPrevalentResource = 339
    , NetworkProcess_IsPrevalentResourceReply = 340
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsVeryPrevalentResource = 341
    , NetworkProcess_IsVeryPrevalentResourceReply = 342
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetAgeCapForClientSideCookies = 343
    , NetworkProcess_SetAgeCapForClientSideCookiesReply = 344
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetLastSeen = 345
    , NetworkProcess_SetLastSeenReply = 346
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_MergeStatisticForTesting = 347
    , NetworkProcess_MergeStatisticForTestingReply = 348
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetPrevalentResource = 349
    , NetworkProcess_SetPrevalentResourceReply = 350
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetPrevalentResourceForDebugMode = 351
    , NetworkProcess_SetPrevalentResourceForDebugModeReply = 352
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsResourceLoadStatisticsEphemeral = 353
    , NetworkProcess_IsResourceLoadStatisticsEphemeralReply = 354
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_HadUserInteraction = 355
    , NetworkProcess_HadUserInteractionReply = 356
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsRelationshipOnlyInDatabaseOnce = 357
    , NetworkProcess_IsRelationshipOnlyInDatabaseOnceReply = 358
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_HasLocalStorage = 359
    , NetworkProcess_HasLocalStorageReply = 360
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_GetAllStorageAccessEntries = 361
    , NetworkProcess_GetAllStorageAccessEntriesReply = 362
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsRegisteredAsRedirectingTo = 363
    , NetworkProcess_IsRegisteredAsRedirectingToReply = 364
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsRegisteredAsSubFrameUnder = 365
    , NetworkProcess_IsRegisteredAsSubFrameUnderReply = 366
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsRegisteredAsSubresourceUnder = 367
    , NetworkProcess_IsRegisteredAsSubresourceUnderReply = 368
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_DomainIDExistsInDatabase = 369
    , NetworkProcess_DomainIDExistsInDatabaseReply = 370
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_LogFrameNavigation = 371
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_LogUserInteraction = 372
    , NetworkProcess_LogUserInteractionReply = 373
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ResetParametersToDefaultValues = 374
    , NetworkProcess_ResetParametersToDefaultValuesReply = 375
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ScheduleClearInMemoryAndPersistent = 376
    , NetworkProcess_ScheduleClearInMemoryAndPersistentReply = 377
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ScheduleCookieBlockingUpdate = 378
    , NetworkProcess_ScheduleCookieBlockingUpdateReply = 379
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ScheduleStatisticsAndDataRecordsProcessing = 380
    , NetworkProcess_ScheduleStatisticsAndDataRecordsProcessingReply = 381
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_StatisticsDatabaseHasAllTables = 382
    , NetworkProcess_StatisticsDatabaseHasAllTablesReply = 383
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SubmitTelemetry = 384
    , NetworkProcess_SubmitTelemetryReply = 385
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetCacheMaxAgeCapForPrevalentResources = 386
    , NetworkProcess_SetCacheMaxAgeCapForPrevalentResourcesReply = 387
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetGrandfathered = 388
    , NetworkProcess_SetGrandfatheredReply = 389
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetUseITPDatabase = 390
    , NetworkProcess_SetUseITPDatabaseReply = 391
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_GetResourceLoadStatisticsDataSummary = 392
    , NetworkProcess_GetResourceLoadStatisticsDataSummaryReply = 393
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetGrandfatheringTime = 394
    , NetworkProcess_SetGrandfatheringTimeReply = 395
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetMaxStatisticsEntries = 396
    , NetworkProcess_SetMaxStatisticsEntriesReply = 397
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetMinimumTimeBetweenDataRecordsRemoval = 398
    , NetworkProcess_SetMinimumTimeBetweenDataRecordsRemovalReply = 399
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetPruneEntriesDownTo = 400
    , NetworkProcess_SetPruneEntriesDownToReply = 401
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemoval = 402
    , NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemovalReply = 403
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetNotifyPagesWhenDataRecordsWereScanned = 404
    , NetworkProcess_SetNotifyPagesWhenDataRecordsWereScannedReply = 405
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetIsRunningResourceLoadStatisticsTest = 406
    , NetworkProcess_SetIsRunningResourceLoadStatisticsTestReply = 407
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetNotifyPagesWhenTelemetryWasCaptured = 408
    , NetworkProcess_SetNotifyPagesWhenTelemetryWasCapturedReply = 409
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetResourceLoadStatisticsDebugMode = 410
    , NetworkProcess_SetResourceLoadStatisticsDebugModeReply = 411
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetVeryPrevalentResource = 412
    , NetworkProcess_SetVeryPrevalentResourceReply = 413
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetSubframeUnderTopFrameDomain = 414
    , NetworkProcess_SetSubframeUnderTopFrameDomainReply = 415
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetSubresourceUnderTopFrameDomain = 416
    , NetworkProcess_SetSubresourceUnderTopFrameDomainReply = 417
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetSubresourceUniqueRedirectTo = 418
    , NetworkProcess_SetSubresourceUniqueRedirectToReply = 419
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetSubresourceUniqueRedirectFrom = 420
    , NetworkProcess_SetSubresourceUniqueRedirectFromReply = 421
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetTimeToLiveUserInteraction = 422
    , NetworkProcess_SetTimeToLiveUserInteractionReply = 423
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetTopFrameUniqueRedirectTo = 424
    , NetworkProcess_SetTopFrameUniqueRedirectToReply = 425
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetTopFrameUniqueRedirectFrom = 426
    , NetworkProcess_SetTopFrameUniqueRedirectFromReply = 427
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ResetCacheMaxAgeCapForPrevalentResources = 428
    , NetworkProcess_ResetCacheMaxAgeCapForPrevalentResourcesReply = 429
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_DidCommitCrossSiteLoadWithDataTransfer = 430
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTesting = 431
    , NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTestingReply = 432
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTesting = 433
    , NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTestingReply = 434
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_DeleteCookiesForTesting = 435
    , NetworkProcess_DeleteCookiesForTestingReply = 436
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_HasIsolatedSession = 437
    , NetworkProcess_HasIsolatedSessionReply = 438
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetAppBoundDomainsForResourceLoadStatistics = 439
    , NetworkProcess_SetAppBoundDomainsForResourceLoadStatisticsReply = 440
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetShouldDowngradeReferrerForTesting = 441
    , NetworkProcess_SetShouldDowngradeReferrerForTestingReply = 442
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetThirdPartyCookieBlockingMode = 443
    , NetworkProcess_SetThirdPartyCookieBlockingModeReply = 444
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTesting = 445
    , NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTestingReply = 446
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTesting = 447
    , NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTestingReply = 448
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetToSameSiteStrictCookiesForTesting = 449
    , NetworkProcess_SetToSameSiteStrictCookiesForTestingReply = 450
#endif
    , NetworkProcess_SetAdClickAttributionDebugMode = 451
    , NetworkProcess_SetSessionIsControlledByAutomation = 452
    , NetworkProcess_RegisterURLSchemeAsSecure = 453
    , NetworkProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy = 454
    , NetworkProcess_RegisterURLSchemeAsLocal = 455
    , NetworkProcess_RegisterURLSchemeAsNoAccess = 456
    , NetworkProcess_SetCacheStorageParameters = 457
    , NetworkProcess_SyncLocalStorage = 458
    , NetworkProcess_ClearLegacyPrivateBrowsingLocalStorage = 459
    , NetworkProcess_StoreAdClickAttribution = 460
    , NetworkProcess_DumpAdClickAttribution = 461
    , NetworkProcess_DumpAdClickAttributionReply = 462
    , NetworkProcess_ClearAdClickAttribution = 463
    , NetworkProcess_ClearAdClickAttributionReply = 464
    , NetworkProcess_SetAdClickAttributionOverrideTimerForTesting = 465
    , NetworkProcess_SetAdClickAttributionOverrideTimerForTestingReply = 466
    , NetworkProcess_SetAdClickAttributionConversionURLForTesting = 467
    , NetworkProcess_SetAdClickAttributionConversionURLForTestingReply = 468
    , NetworkProcess_MarkAdClickAttributionsAsExpiredForTesting = 469
    , NetworkProcess_MarkAdClickAttributionsAsExpiredForTestingReply = 470
    , NetworkProcess_GetLocalStorageOriginDetails = 471
    , NetworkProcess_GetLocalStorageOriginDetailsReply = 472
    , NetworkProcess_SetServiceWorkerFetchTimeoutForTesting = 473
    , NetworkProcess_ResetServiceWorkerFetchTimeoutForTesting = 474
    , NetworkProcess_ResetQuota = 475
    , NetworkProcess_ResetQuotaReply = 476
    , NetworkProcess_HasAppBoundSession = 477
    , NetworkProcess_HasAppBoundSessionReply = 478
    , NetworkProcess_ClearAppBoundSession = 479
    , NetworkProcess_ClearAppBoundSessionReply = 480
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    , NetworkProcess_DisableServiceWorkerEntitlement = 481
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    , NetworkProcess_ClearServiceWorkerEntitlementOverride = 482
    , NetworkProcess_ClearServiceWorkerEntitlementOverrideReply = 483
#endif
    , NetworkResourceLoader_ContinueWillSendRequest = 484
    , NetworkResourceLoader_ContinueDidReceiveResponse = 485
    , NetworkSocketChannel_SendString = 486
    , NetworkSocketChannel_SendStringReply = 487
    , NetworkSocketChannel_SendData = 488
    , NetworkSocketChannel_SendDataReply = 489
    , NetworkSocketChannel_Close = 490
    , NetworkSocketStream_SendData = 491
    , NetworkSocketStream_SendHandshake = 492
    , NetworkSocketStream_Close = 493
    , ServiceWorkerFetchTask_DidNotHandle = 494
    , ServiceWorkerFetchTask_DidFail = 495
    , ServiceWorkerFetchTask_DidReceiveRedirectResponse = 496
    , ServiceWorkerFetchTask_DidReceiveResponse = 497
    , ServiceWorkerFetchTask_DidReceiveData = 498
    , ServiceWorkerFetchTask_DidReceiveSharedBuffer = 499
    , ServiceWorkerFetchTask_DidReceiveFormData = 500
    , ServiceWorkerFetchTask_DidFinish = 501
    , WebSWServerConnection_ScheduleJobInServer = 502
    , WebSWServerConnection_ScheduleUnregisterJobInServer = 503
    , WebSWServerConnection_ScheduleUnregisterJobInServerReply = 504
    , WebSWServerConnection_FinishFetchingScriptInServer = 505
    , WebSWServerConnection_AddServiceWorkerRegistrationInServer = 506
    , WebSWServerConnection_RemoveServiceWorkerRegistrationInServer = 507
    , WebSWServerConnection_PostMessageToServiceWorker = 508
    , WebSWServerConnection_DidResolveRegistrationPromise = 509
    , WebSWServerConnection_MatchRegistration = 510
    , WebSWServerConnection_WhenRegistrationReady = 511
    , WebSWServerConnection_GetRegistrations = 512
    , WebSWServerConnection_RegisterServiceWorkerClient = 513
    , WebSWServerConnection_UnregisterServiceWorkerClient = 514
    , WebSWServerConnection_TerminateWorkerFromClient = 515
    , WebSWServerConnection_TerminateWorkerFromClientReply = 516
    , WebSWServerConnection_WhenServiceWorkerIsTerminatedForTesting = 517
    , WebSWServerConnection_WhenServiceWorkerIsTerminatedForTestingReply = 518
    , WebSWServerConnection_SetThrottleState = 519
    , WebSWServerConnection_StoreRegistrationsOnDisk = 520
    , WebSWServerConnection_StoreRegistrationsOnDiskReply = 521
    , WebSWServerToContextConnection_ScriptContextFailedToStart = 522
    , WebSWServerToContextConnection_ScriptContextStarted = 523
    , WebSWServerToContextConnection_DidFinishInstall = 524
    , WebSWServerToContextConnection_DidFinishActivation = 525
    , WebSWServerToContextConnection_SetServiceWorkerHasPendingEvents = 526
    , WebSWServerToContextConnection_SkipWaiting = 527
    , WebSWServerToContextConnection_SkipWaitingReply = 528
    , WebSWServerToContextConnection_WorkerTerminated = 529
    , WebSWServerToContextConnection_FindClientByIdentifier = 530
    , WebSWServerToContextConnection_MatchAll = 531
    , WebSWServerToContextConnection_Claim = 532
    , WebSWServerToContextConnection_ClaimReply = 533
    , WebSWServerToContextConnection_SetScriptResource = 534
    , WebSWServerToContextConnection_PostMessageToServiceWorkerClient = 535
    , WebSWServerToContextConnection_DidFailHeartBeatCheck = 536
    , StorageManagerSet_ConnectToLocalStorageArea = 537
    , StorageManagerSet_ConnectToTransientLocalStorageArea = 538
    , StorageManagerSet_ConnectToSessionStorageArea = 539
    , StorageManagerSet_DisconnectFromStorageArea = 540
    , StorageManagerSet_GetValues = 541
    , StorageManagerSet_CloneSessionStorageNamespace = 542
    , StorageManagerSet_SetItem = 543
    , StorageManagerSet_RemoveItem = 544
    , StorageManagerSet_Clear = 545
    , CacheStorageEngineConnection_Reference = 546
    , CacheStorageEngineConnection_Dereference = 547
    , CacheStorageEngineConnection_Open = 548
    , CacheStorageEngineConnection_OpenReply = 549
    , CacheStorageEngineConnection_Remove = 550
    , CacheStorageEngineConnection_RemoveReply = 551
    , CacheStorageEngineConnection_Caches = 552
    , CacheStorageEngineConnection_CachesReply = 553
    , CacheStorageEngineConnection_RetrieveRecords = 554
    , CacheStorageEngineConnection_RetrieveRecordsReply = 555
    , CacheStorageEngineConnection_DeleteMatchingRecords = 556
    , CacheStorageEngineConnection_DeleteMatchingRecordsReply = 557
    , CacheStorageEngineConnection_PutRecords = 558
    , CacheStorageEngineConnection_PutRecordsReply = 559
    , CacheStorageEngineConnection_ClearMemoryRepresentation = 560
    , CacheStorageEngineConnection_ClearMemoryRepresentationReply = 561
    , CacheStorageEngineConnection_EngineRepresentation = 562
    , CacheStorageEngineConnection_EngineRepresentationReply = 563
    , NetworkMDNSRegister_UnregisterMDNSNames = 564
    , NetworkMDNSRegister_RegisterMDNSName = 565
    , NetworkRTCMonitor_StartUpdatingIfNeeded = 566
    , NetworkRTCMonitor_StopUpdating = 567
    , NetworkRTCProvider_CreateUDPSocket = 568
    , NetworkRTCProvider_CreateServerTCPSocket = 569
    , NetworkRTCProvider_CreateClientTCPSocket = 570
    , NetworkRTCProvider_WrapNewTCPConnection = 571
    , NetworkRTCProvider_CreateResolver = 572
    , NetworkRTCProvider_StopResolver = 573
    , NetworkRTCSocket_SendTo = 574
    , NetworkRTCSocket_Close = 575
    , NetworkRTCSocket_SetOption = 576
    , PluginControllerProxy_GeometryDidChange = 577
    , PluginControllerProxy_VisibilityDidChange = 578
    , PluginControllerProxy_FrameDidFinishLoading = 579
    , PluginControllerProxy_FrameDidFail = 580
    , PluginControllerProxy_DidEvaluateJavaScript = 581
    , PluginControllerProxy_StreamWillSendRequest = 582
    , PluginControllerProxy_StreamDidReceiveResponse = 583
    , PluginControllerProxy_StreamDidReceiveData = 584
    , PluginControllerProxy_StreamDidFinishLoading = 585
    , PluginControllerProxy_StreamDidFail = 586
    , PluginControllerProxy_ManualStreamDidReceiveResponse = 587
    , PluginControllerProxy_ManualStreamDidReceiveData = 588
    , PluginControllerProxy_ManualStreamDidFinishLoading = 589
    , PluginControllerProxy_ManualStreamDidFail = 590
    , PluginControllerProxy_HandleMouseEvent = 591
    , PluginControllerProxy_HandleWheelEvent = 592
    , PluginControllerProxy_HandleMouseEnterEvent = 593
    , PluginControllerProxy_HandleMouseLeaveEvent = 594
    , PluginControllerProxy_HandleKeyboardEvent = 595
    , PluginControllerProxy_HandleEditingCommand = 596
    , PluginControllerProxy_IsEditingCommandEnabled = 597
    , PluginControllerProxy_HandlesPageScaleFactor = 598
    , PluginControllerProxy_RequiresUnifiedScaleFactor = 599
    , PluginControllerProxy_SetFocus = 600
    , PluginControllerProxy_DidUpdate = 601
    , PluginControllerProxy_PaintEntirePlugin = 602
    , PluginControllerProxy_GetPluginScriptableNPObject = 603
    , PluginControllerProxy_WindowFocusChanged = 604
    , PluginControllerProxy_WindowVisibilityChanged = 605
#if PLATFORM(COCOA)
    , PluginControllerProxy_SendComplexTextInput = 606
#endif
#if PLATFORM(COCOA)
    , PluginControllerProxy_WindowAndViewFramesChanged = 607
#endif
#if PLATFORM(COCOA)
    , PluginControllerProxy_SetLayerHostingMode = 608
#endif
    , PluginControllerProxy_SupportsSnapshotting = 609
    , PluginControllerProxy_Snapshot = 610
    , PluginControllerProxy_StorageBlockingStateChanged = 611
    , PluginControllerProxy_PrivateBrowsingStateChanged = 612
    , PluginControllerProxy_GetFormValue = 613
    , PluginControllerProxy_MutedStateChanged = 614
    , PluginProcess_InitializePluginProcess = 615
    , PluginProcess_CreateWebProcessConnection = 616
    , PluginProcess_GetSitesWithData = 617
    , PluginProcess_DeleteWebsiteData = 618
    , PluginProcess_DeleteWebsiteDataForHostNames = 619
#if PLATFORM(COCOA)
    , PluginProcess_SetQOS = 620
#endif
    , WebProcessConnection_CreatePlugin = 621
    , WebProcessConnection_CreatePluginAsynchronously = 622
    , WebProcessConnection_DestroyPlugin = 623
    , AuxiliaryProcess_ShutDown = 624
    , AuxiliaryProcess_SetProcessSuppressionEnabled = 625
#if OS(LINUX)
    , AuxiliaryProcess_DidReceiveMemoryPressureEvent = 626
#endif
    , WebConnection_HandleMessage = 627
    , AuthenticationManager_CompleteAuthenticationChallenge = 628
    , NPObjectMessageReceiver_Deallocate = 629
    , NPObjectMessageReceiver_HasMethod = 630
    , NPObjectMessageReceiver_Invoke = 631
    , NPObjectMessageReceiver_InvokeDefault = 632
    , NPObjectMessageReceiver_HasProperty = 633
    , NPObjectMessageReceiver_GetProperty = 634
    , NPObjectMessageReceiver_SetProperty = 635
    , NPObjectMessageReceiver_RemoveProperty = 636
    , NPObjectMessageReceiver_Enumerate = 637
    , NPObjectMessageReceiver_Construct = 638
    , DrawingAreaProxy_EnterAcceleratedCompositingMode = 639
    , DrawingAreaProxy_UpdateAcceleratedCompositingMode = 640
    , DrawingAreaProxy_DidFirstLayerFlush = 641
    , DrawingAreaProxy_DispatchPresentationCallbacksAfterFlushingLayers = 642
#if PLATFORM(COCOA)
    , DrawingAreaProxy_DidUpdateGeometry = 643
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    , DrawingAreaProxy_Update = 644
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    , DrawingAreaProxy_DidUpdateBackingStoreState = 645
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    , DrawingAreaProxy_ExitAcceleratedCompositingMode = 646
#endif
    , VisitedLinkStore_AddVisitedLinkHashFromPage = 647
    , WebCookieManagerProxy_CookiesDidChange = 648
    , WebFullScreenManagerProxy_SupportsFullScreen = 649
    , WebFullScreenManagerProxy_EnterFullScreen = 650
    , WebFullScreenManagerProxy_ExitFullScreen = 651
    , WebFullScreenManagerProxy_BeganEnterFullScreen = 652
    , WebFullScreenManagerProxy_BeganExitFullScreen = 653
    , WebFullScreenManagerProxy_Close = 654
    , WebGeolocationManagerProxy_StartUpdating = 655
    , WebGeolocationManagerProxy_StopUpdating = 656
    , WebGeolocationManagerProxy_SetEnableHighAccuracy = 657
    , WebPageProxy_CreateNewPage = 658
    , WebPageProxy_ShowPage = 659
    , WebPageProxy_ClosePage = 660
    , WebPageProxy_RunJavaScriptAlert = 661
    , WebPageProxy_RunJavaScriptConfirm = 662
    , WebPageProxy_RunJavaScriptPrompt = 663
    , WebPageProxy_MouseDidMoveOverElement = 664
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_UnavailablePluginButtonClicked = 665
#endif
#if ENABLE(WEBGL)
    , WebPageProxy_WebGLPolicyForURL = 666
#endif
#if ENABLE(WEBGL)
    , WebPageProxy_ResolveWebGLPolicyForURL = 667
#endif
    , WebPageProxy_DidChangeViewportProperties = 668
    , WebPageProxy_DidReceiveEvent = 669
    , WebPageProxy_SetCursor = 670
    , WebPageProxy_SetCursorHiddenUntilMouseMoves = 671
    , WebPageProxy_SetStatusText = 672
    , WebPageProxy_SetFocus = 673
    , WebPageProxy_TakeFocus = 674
    , WebPageProxy_FocusedFrameChanged = 675
    , WebPageProxy_SetRenderTreeSize = 676
    , WebPageProxy_SetToolbarsAreVisible = 677
    , WebPageProxy_GetToolbarsAreVisible = 678
    , WebPageProxy_SetMenuBarIsVisible = 679
    , WebPageProxy_GetMenuBarIsVisible = 680
    , WebPageProxy_SetStatusBarIsVisible = 681
    , WebPageProxy_GetStatusBarIsVisible = 682
    , WebPageProxy_SetIsResizable = 683
    , WebPageProxy_SetWindowFrame = 684
    , WebPageProxy_GetWindowFrame = 685
    , WebPageProxy_ScreenToRootView = 686
    , WebPageProxy_RootViewToScreen = 687
    , WebPageProxy_AccessibilityScreenToRootView = 688
    , WebPageProxy_RootViewToAccessibilityScreen = 689
#if PLATFORM(COCOA)
    , WebPageProxy_ShowValidationMessage = 690
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_HideValidationMessage = 691
#endif
    , WebPageProxy_RunBeforeUnloadConfirmPanel = 692
    , WebPageProxy_PageDidScroll = 693
    , WebPageProxy_RunOpenPanel = 694
    , WebPageProxy_ShowShareSheet = 695
    , WebPageProxy_ShowShareSheetReply = 696
    , WebPageProxy_PrintFrame = 697
    , WebPageProxy_RunModal = 698
    , WebPageProxy_NotifyScrollerThumbIsVisibleInRect = 699
    , WebPageProxy_RecommendedScrollbarStyleDidChange = 700
    , WebPageProxy_DidChangeScrollbarsForMainFrame = 701
    , WebPageProxy_DidChangeScrollOffsetPinningForMainFrame = 702
    , WebPageProxy_DidChangePageCount = 703
    , WebPageProxy_PageExtendedBackgroundColorDidChange = 704
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_DidFailToInitializePlugin = 705
#endif
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_DidBlockInsecurePluginVersion = 706
#endif
    , WebPageProxy_SetCanShortCircuitHorizontalWheelEvents = 707
    , WebPageProxy_DidChangeContentSize = 708
    , WebPageProxy_DidChangeIntrinsicContentSize = 709
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPageProxy_ShowColorPicker = 710
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPageProxy_SetColorPickerColor = 711
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPageProxy_EndColorPicker = 712
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPageProxy_ShowDataListSuggestions = 713
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPageProxy_HandleKeydownInDataList = 714
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPageProxy_EndDataListSuggestions = 715
#endif
    , WebPageProxy_DecidePolicyForResponse = 716
    , WebPageProxy_DecidePolicyForNavigationActionAsync = 717
    , WebPageProxy_DecidePolicyForNavigationActionSync = 718
    , WebPageProxy_DecidePolicyForNewWindowAction = 719
    , WebPageProxy_UnableToImplementPolicy = 720
    , WebPageProxy_DidChangeProgress = 721
    , WebPageProxy_DidFinishProgress = 722
    , WebPageProxy_DidStartProgress = 723
    , WebPageProxy_SetNetworkRequestsInProgress = 724
    , WebPageProxy_DidCreateMainFrame = 725
    , WebPageProxy_DidCreateSubframe = 726
    , WebPageProxy_DidCreateWindow = 727
    , WebPageProxy_DidStartProvisionalLoadForFrame = 728
    , WebPageProxy_DidReceiveServerRedirectForProvisionalLoadForFrame = 729
    , WebPageProxy_WillPerformClientRedirectForFrame = 730
    , WebPageProxy_DidCancelClientRedirectForFrame = 731
    , WebPageProxy_DidChangeProvisionalURLForFrame = 732
    , WebPageProxy_DidFailProvisionalLoadForFrame = 733
    , WebPageProxy_DidCommitLoadForFrame = 734
    , WebPageProxy_DidFailLoadForFrame = 735
    , WebPageProxy_DidFinishDocumentLoadForFrame = 736
    , WebPageProxy_DidFinishLoadForFrame = 737
    , WebPageProxy_DidFirstLayoutForFrame = 738
    , WebPageProxy_DidFirstVisuallyNonEmptyLayoutForFrame = 739
    , WebPageProxy_DidReachLayoutMilestone = 740
    , WebPageProxy_DidReceiveTitleForFrame = 741
    , WebPageProxy_DidDisplayInsecureContentForFrame = 742
    , WebPageProxy_DidRunInsecureContentForFrame = 743
    , WebPageProxy_DidDetectXSSForFrame = 744
    , WebPageProxy_DidSameDocumentNavigationForFrame = 745
    , WebPageProxy_DidChangeMainDocument = 746
    , WebPageProxy_DidExplicitOpenForFrame = 747
    , WebPageProxy_DidDestroyNavigation = 748
    , WebPageProxy_MainFramePluginHandlesPageScaleGestureDidChange = 749
    , WebPageProxy_DidNavigateWithNavigationData = 750
    , WebPageProxy_DidPerformClientRedirect = 751
    , WebPageProxy_DidPerformServerRedirect = 752
    , WebPageProxy_DidUpdateHistoryTitle = 753
    , WebPageProxy_DidFinishLoadingDataForCustomContentProvider = 754
    , WebPageProxy_WillSubmitForm = 755
    , WebPageProxy_VoidCallback = 756
    , WebPageProxy_DataCallback = 757
    , WebPageProxy_ImageCallback = 758
    , WebPageProxy_StringCallback = 759
    , WebPageProxy_BoolCallback = 760
    , WebPageProxy_InvalidateStringCallback = 761
    , WebPageProxy_ScriptValueCallback = 762
    , WebPageProxy_ComputedPagesCallback = 763
    , WebPageProxy_ValidateCommandCallback = 764
    , WebPageProxy_EditingRangeCallback = 765
    , WebPageProxy_UnsignedCallback = 766
    , WebPageProxy_RectForCharacterRangeCallback = 767
#if ENABLE(APPLICATION_MANIFEST)
    , WebPageProxy_ApplicationManifestCallback = 768
#endif
#if PLATFORM(MAC)
    , WebPageProxy_AttributedStringForCharacterRangeCallback = 769
#endif
#if PLATFORM(MAC)
    , WebPageProxy_FontAtSelectionCallback = 770
#endif
    , WebPageProxy_FontAttributesCallback = 771
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_GestureCallback = 772
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_TouchesCallback = 773
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_SelectionContextCallback = 774
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_InterpretKeyEvent = 775
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DidReceivePositionInformation = 776
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_SaveImageToLibrary = 777
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowPlaybackTargetPicker = 778
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_CommitPotentialTapFailed = 779
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DidNotHandleTapAsClick = 780
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DidCompleteSyntheticClick = 781
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DisableDoubleTapGesturesDuringTapIfNecessary = 782
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_HandleSmartMagnificationInformationForPotentialTap = 783
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_SelectionRectsCallback = 784
#endif
#if ENABLE(DATA_DETECTION)
    , WebPageProxy_SetDataDetectionResult = 785
#endif
#if PLATFORM(GTK)
    , WebPageProxy_PrintFinishedCallback = 786
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_DrawToPDFCallback = 787
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_NowPlayingInfoCallback = 788
#endif
    , WebPageProxy_FindStringCallback = 789
    , WebPageProxy_PageScaleFactorDidChange = 790
    , WebPageProxy_PluginScaleFactorDidChange = 791
    , WebPageProxy_PluginZoomFactorDidChange = 792
#if USE(ATK)
    , WebPageProxy_BindAccessibilityTree = 793
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPageProxy_SetInputMethodState = 794
#endif
    , WebPageProxy_BackForwardAddItem = 795
    , WebPageProxy_BackForwardGoToItem = 796
    , WebPageProxy_BackForwardItemAtIndex = 797
    , WebPageProxy_BackForwardListCounts = 798
    , WebPageProxy_BackForwardClear = 799
    , WebPageProxy_WillGoToBackForwardListItem = 800
    , WebPageProxy_RegisterEditCommandForUndo = 801
    , WebPageProxy_ClearAllEditCommands = 802
    , WebPageProxy_RegisterInsertionUndoGrouping = 803
    , WebPageProxy_CanUndoRedo = 804
    , WebPageProxy_ExecuteUndoRedo = 805
    , WebPageProxy_LogDiagnosticMessage = 806
    , WebPageProxy_LogDiagnosticMessageWithResult = 807
    , WebPageProxy_LogDiagnosticMessageWithValue = 808
    , WebPageProxy_LogDiagnosticMessageWithEnhancedPrivacy = 809
    , WebPageProxy_LogDiagnosticMessageWithValueDictionary = 810
    , WebPageProxy_LogScrollingEvent = 811
    , WebPageProxy_EditorStateChanged = 812
    , WebPageProxy_CompositionWasCanceled = 813
    , WebPageProxy_SetHasHadSelectionChangesFromUserInteraction = 814
#if HAVE(TOUCH_BAR)
    , WebPageProxy_SetIsTouchBarUpdateSupressedForHiddenContentEditable = 815
#endif
#if HAVE(TOUCH_BAR)
    , WebPageProxy_SetIsNeverRichlyEditableForTouchBar = 816
#endif
    , WebPageProxy_RequestDOMPasteAccess = 817
    , WebPageProxy_DidCountStringMatches = 818
    , WebPageProxy_SetTextIndicator = 819
    , WebPageProxy_ClearTextIndicator = 820
    , WebPageProxy_DidFindString = 821
    , WebPageProxy_DidFailToFindString = 822
    , WebPageProxy_DidFindStringMatches = 823
    , WebPageProxy_DidGetImageForFindMatch = 824
    , WebPageProxy_ShowPopupMenu = 825
    , WebPageProxy_HidePopupMenu = 826
#if ENABLE(CONTEXT_MENUS)
    , WebPageProxy_ShowContextMenu = 827
#endif
    , WebPageProxy_ExceededDatabaseQuota = 828
    , WebPageProxy_ReachedApplicationCacheOriginQuota = 829
    , WebPageProxy_RequestGeolocationPermissionForFrame = 830
    , WebPageProxy_RevokeGeolocationAuthorizationToken = 831
#if ENABLE(MEDIA_STREAM)
    , WebPageProxy_RequestUserMediaPermissionForFrame = 832
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPageProxy_EnumerateMediaDevicesForFrame = 833
    , WebPageProxy_EnumerateMediaDevicesForFrameReply = 834
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPageProxy_BeginMonitoringCaptureDevices = 835
#endif
    , WebPageProxy_RequestNotificationPermission = 836
    , WebPageProxy_ShowNotification = 837
    , WebPageProxy_CancelNotification = 838
    , WebPageProxy_ClearNotifications = 839
    , WebPageProxy_DidDestroyNotification = 840
#if USE(UNIFIED_TEXT_CHECKING)
    , WebPageProxy_CheckTextOfParagraph = 841
#endif
    , WebPageProxy_CheckSpellingOfString = 842
    , WebPageProxy_CheckGrammarOfString = 843
    , WebPageProxy_SpellingUIIsShowing = 844
    , WebPageProxy_UpdateSpellingUIWithMisspelledWord = 845
    , WebPageProxy_UpdateSpellingUIWithGrammarString = 846
    , WebPageProxy_GetGuessesForWord = 847
    , WebPageProxy_LearnWord = 848
    , WebPageProxy_IgnoreWord = 849
    , WebPageProxy_RequestCheckingOfString = 850
#if ENABLE(DRAG_SUPPORT)
    , WebPageProxy_DidPerformDragControllerAction = 851
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPageProxy_DidEndDragging = 852
#endif
#if PLATFORM(COCOA) && ENABLE(DRAG_SUPPORT)
    , WebPageProxy_StartDrag = 853
#endif
#if PLATFORM(COCOA) && ENABLE(DRAG_SUPPORT)
    , WebPageProxy_SetPromisedDataForImage = 854
#endif
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    , WebPageProxy_StartDrag = 855
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPageProxy_DidPerformDragOperation = 856
#endif
#if ENABLE(DATA_INTERACTION)
    , WebPageProxy_DidHandleDragStartRequest = 857
#endif
#if ENABLE(DATA_INTERACTION)
    , WebPageProxy_DidHandleAdditionalDragItemsRequest = 858
#endif
#if ENABLE(DATA_INTERACTION)
    , WebPageProxy_WillReceiveEditDragSnapshot = 859
#endif
#if ENABLE(DATA_INTERACTION)
    , WebPageProxy_DidReceiveEditDragSnapshot = 860
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_DidPerformDictionaryLookup = 861
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_ExecuteSavedCommandBySelector = 862
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_RegisterWebProcessAccessibilityToken = 863
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_PluginFocusOrWindowFocusChanged = 864
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_SetPluginComplexTextInputState = 865
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_GetIsSpeaking = 866
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_Speak = 867
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_StopSpeaking = 868
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_MakeFirstResponder = 869
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_AssistiveTechnologyMakeFirstResponder = 870
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_SearchWithSpotlight = 871
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_SearchTheWeb = 872
#endif
#if HAVE(TOUCH_BAR)
    , WebPageProxy_TouchBarMenuDataChanged = 873
#endif
#if HAVE(TOUCH_BAR)
    , WebPageProxy_TouchBarMenuItemDataAdded = 874
#endif
#if HAVE(TOUCH_BAR)
    , WebPageProxy_TouchBarMenuItemDataRemoved = 875
#endif
#if USE(APPKIT)
    , WebPageProxy_SubstitutionsPanelIsShowing = 876
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleSmartInsertDelete = 877
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleAutomaticQuoteSubstitution = 878
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleAutomaticLinkDetection = 879
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleAutomaticDashSubstitution = 880
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleAutomaticTextReplacement = 881
#endif
#if PLATFORM(MAC)
    , WebPageProxy_ShowCorrectionPanel = 882
#endif
#if PLATFORM(MAC)
    , WebPageProxy_DismissCorrectionPanel = 883
#endif
#if PLATFORM(MAC)
    , WebPageProxy_DismissCorrectionPanelSoon = 884
#endif
#if PLATFORM(MAC)
    , WebPageProxy_RecordAutocorrectionResponse = 885
#endif
#if PLATFORM(MAC)
    , WebPageProxy_SetEditableElementIsFocused = 886
#endif
#if USE(DICTATION_ALTERNATIVES)
    , WebPageProxy_ShowDictationAlternativeUI = 887
#endif
#if USE(DICTATION_ALTERNATIVES)
    , WebPageProxy_RemoveDictationAlternatives = 888
#endif
#if USE(DICTATION_ALTERNATIVES)
    , WebPageProxy_DictationAlternatives = 889
#endif
#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_CreatePluginContainer = 890
#endif
#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_WindowedPluginGeometryDidChange = 891
#endif
#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_WindowedPluginVisibilityDidChange = 892
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_CouldNotRestorePageState = 893
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_RestorePageState = 894
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_RestorePageCenterAndScale = 895
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DidGetTapHighlightGeometries = 896
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ElementDidFocus = 897
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ElementDidBlur = 898
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_UpdateInputContextAfterBlurringAndRefocusingElement = 899
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_FocusedElementDidChangeInputMode = 900
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ScrollingNodeScrollWillStartScroll = 901
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ScrollingNodeScrollDidEndScroll = 902
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowInspectorHighlight = 903
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_HideInspectorHighlight = 904
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_FocusedElementInformationCallback = 905
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowInspectorIndication = 906
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_HideInspectorIndication = 907
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_EnableInspectorNodeSearch = 908
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DisableInspectorNodeSearch = 909
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_UpdateStringForFind = 910
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_HandleAutocorrectionContext = 911
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowDataDetectorsUIForPositionInformation = 912
#endif
    , WebPageProxy_DidChangeInspectorFrontendCount = 913
    , WebPageProxy_CreateInspectorTarget = 914
    , WebPageProxy_DestroyInspectorTarget = 915
    , WebPageProxy_SendMessageToInspectorFrontend = 916
    , WebPageProxy_SaveRecentSearches = 917
    , WebPageProxy_LoadRecentSearches = 918
    , WebPageProxy_SavePDFToFileInDownloadsFolder = 919
#if PLATFORM(COCOA)
    , WebPageProxy_SavePDFToTemporaryFolderAndOpenWithNativeApplication = 920
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_OpenPDFFromTemporaryFolderWithNativeApplication = 921
#endif
#if ENABLE(PDFKIT_PLUGIN)
    , WebPageProxy_ShowPDFContextMenu = 922
#endif
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_FindPlugin = 923
#endif
    , WebPageProxy_DidUpdateActivityState = 924
#if ENABLE(WEB_CRYPTO)
    , WebPageProxy_WrapCryptoKey = 925
#endif
#if ENABLE(WEB_CRYPTO)
    , WebPageProxy_UnwrapCryptoKey = 926
#endif
#if (ENABLE(TELEPHONE_NUMBER_DETECTION) && PLATFORM(MAC))
    , WebPageProxy_ShowTelephoneNumberMenu = 927
#endif
#if USE(QUICK_LOOK)
    , WebPageProxy_DidStartLoadForQuickLookDocumentInMainFrame = 928
#endif
#if USE(QUICK_LOOK)
    , WebPageProxy_DidFinishLoadForQuickLookDocumentInMainFrame = 929
#endif
#if USE(QUICK_LOOK)
    , WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrame = 930
    , WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrameReply = 931
#endif
#if ENABLE(CONTENT_FILTERING)
    , WebPageProxy_ContentFilterDidBlockLoadForFrame = 932
#endif
    , WebPageProxy_IsPlayingMediaDidChange = 933
    , WebPageProxy_HandleAutoplayEvent = 934
#if ENABLE(MEDIA_SESSION)
    , WebPageProxy_HasMediaSessionWithActiveMediaElementsDidChange = 935
#endif
#if ENABLE(MEDIA_SESSION)
    , WebPageProxy_MediaSessionMetadataDidChange = 936
#endif
#if ENABLE(MEDIA_SESSION)
    , WebPageProxy_FocusedContentMediaElementDidChange = 937
#endif
#if PLATFORM(MAC)
    , WebPageProxy_DidPerformImmediateActionHitTest = 938
#endif
    , WebPageProxy_HandleMessage = 939
    , WebPageProxy_HandleSynchronousMessage = 940
    , WebPageProxy_HandleAutoFillButtonClick = 941
    , WebPageProxy_DidResignInputElementStrongPasswordAppearance = 942
    , WebPageProxy_ContentRuleListNotification = 943
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_AddPlaybackTargetPickerClient = 944
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_RemovePlaybackTargetPickerClient = 945
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowPlaybackTargetPicker = 946
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_PlaybackTargetPickerClientStateDidChange = 947
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_SetMockMediaPlaybackTargetPickerEnabled = 948
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_SetMockMediaPlaybackTargetPickerState = 949
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_MockMediaPlaybackTargetPickerDismissPopup = 950
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , WebPageProxy_SetMockVideoPresentationModeEnabled = 951
#endif
#if ENABLE(POINTER_LOCK)
    , WebPageProxy_RequestPointerLock = 952
#endif
#if ENABLE(POINTER_LOCK)
    , WebPageProxy_RequestPointerUnlock = 953
#endif
    , WebPageProxy_DidFailToSuspendAfterProcessSwap = 954
    , WebPageProxy_DidSuspendAfterProcessSwap = 955
    , WebPageProxy_ImageOrMediaDocumentSizeChanged = 956
    , WebPageProxy_UseFixedLayoutDidChange = 957
    , WebPageProxy_FixedLayoutSizeDidChange = 958
#if ENABLE(VIDEO) && USE(GSTREAMER)
    , WebPageProxy_RequestInstallMissingMediaPlugins = 959
#endif
    , WebPageProxy_DidRestoreScrollPosition = 960
    , WebPageProxy_GetLoadDecisionForIcon = 961
    , WebPageProxy_FinishedLoadingIcon = 962
#if PLATFORM(MAC)
    , WebPageProxy_DidHandleAcceptedCandidate = 963
#endif
    , WebPageProxy_SetIsUsingHighPerformanceWebGL = 964
    , WebPageProxy_StartURLSchemeTask = 965
    , WebPageProxy_StopURLSchemeTask = 966
    , WebPageProxy_LoadSynchronousURLSchemeTask = 967
#if ENABLE(DEVICE_ORIENTATION)
    , WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccess = 968
    , WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccessReply = 969
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_RegisterAttachmentIdentifierFromData = 970
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_RegisterAttachmentIdentifierFromFilePath = 971
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_RegisterAttachmentIdentifier = 972
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_RegisterAttachmentsFromSerializedData = 973
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_CloneAttachmentData = 974
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_DidInsertAttachmentWithIdentifier = 975
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_DidRemoveAttachmentWithIdentifier = 976
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_SerializedAttachmentDataForIdentifiers = 977
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_WritePromisedAttachmentToPasteboard = 978
#endif
    , WebPageProxy_SignedPublicKeyAndChallengeString = 979
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisVoiceList = 980
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisSpeak = 981
    , WebPageProxy_SpeechSynthesisSpeakReply = 982
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisSetFinishedCallback = 983
    , WebPageProxy_SpeechSynthesisSetFinishedCallbackReply = 984
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisCancel = 985
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisPause = 986
    , WebPageProxy_SpeechSynthesisPauseReply = 987
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisResume = 988
    , WebPageProxy_SpeechSynthesisResumeReply = 989
#endif
    , WebPageProxy_ConfigureLoggingChannel = 990
#if PLATFORM(GTK)
    , WebPageProxy_ShowEmojiPicker = 991
    , WebPageProxy_ShowEmojiPickerReply = 992
#endif
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    , WebPageProxy_DidCreateContextForVisibilityPropagation = 993
#endif
#if ENABLE(WEB_AUTHN)
    , WebPageProxy_SetMockWebAuthenticationConfiguration = 994
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPageProxy_SendMessageToWebView = 995
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPageProxy_SendMessageToWebViewWithReply = 996
    , WebPageProxy_SendMessageToWebViewWithReplyReply = 997
#endif
    , WebPageProxy_DidFindTextManipulationItems = 998
#if ENABLE(MEDIA_USAGE)
    , WebPageProxy_AddMediaUsageManagerSession = 999
#endif
#if ENABLE(MEDIA_USAGE)
    , WebPageProxy_UpdateMediaUsageManagerSessionState = 1000
#endif
#if ENABLE(MEDIA_USAGE)
    , WebPageProxy_RemoveMediaUsageManagerSession = 1001
#endif
    , WebPageProxy_SetHasExecutedAppBoundBehaviorBeforeNavigation = 1002
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_WriteURLToPasteboard = 1003
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_WriteWebContentToPasteboard = 1004
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_WriteImageToPasteboard = 1005
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_WriteStringToPasteboard = 1006
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_UpdateSupportedTypeIdentifiers = 1007
#endif
    , WebPasteboardProxy_WriteCustomData = 1008
    , WebPasteboardProxy_TypesSafeForDOMToReadAndWrite = 1009
    , WebPasteboardProxy_AllPasteboardItemInfo = 1010
    , WebPasteboardProxy_InformationForItemAtIndex = 1011
    , WebPasteboardProxy_GetPasteboardItemsCount = 1012
    , WebPasteboardProxy_ReadStringFromPasteboard = 1013
    , WebPasteboardProxy_ReadURLFromPasteboard = 1014
    , WebPasteboardProxy_ReadBufferFromPasteboard = 1015
    , WebPasteboardProxy_ContainsStringSafeForDOMToReadForType = 1016
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetNumberOfFiles = 1017
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardTypes = 1018
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardPathnamesForType = 1019
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardStringForType = 1020
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardStringsForType = 1021
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardBufferForType = 1022
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardChangeCount = 1023
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardColor = 1024
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardURL = 1025
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_AddPasteboardTypes = 1026
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardTypes = 1027
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardURL = 1028
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardColor = 1029
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardStringForType = 1030
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardBufferForType = 1031
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_ContainsURLStringSuitableForLoading = 1032
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_URLStringSuitableForLoading = 1033
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_GetTypes = 1034
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_ReadText = 1035
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_ReadFilePaths = 1036
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_ReadBuffer = 1037
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_WriteToClipboard = 1038
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_ClearClipboard = 1039
#endif
#if USE(LIBWPE)
    , WebPasteboardProxy_GetPasteboardTypes = 1040
#endif
#if USE(LIBWPE)
    , WebPasteboardProxy_WriteWebContentToPasteboard = 1041
#endif
#if USE(LIBWPE)
    , WebPasteboardProxy_WriteStringToPasteboard = 1042
#endif
    , WebProcessPool_HandleMessage = 1043
    , WebProcessPool_HandleSynchronousMessage = 1044
#if ENABLE(GAMEPAD)
    , WebProcessPool_StartedUsingGamepads = 1045
#endif
#if ENABLE(GAMEPAD)
    , WebProcessPool_StoppedUsingGamepads = 1046
#endif
    , WebProcessPool_ReportWebContentCPUTime = 1047
    , WebProcessProxy_UpdateBackForwardItem = 1048
    , WebProcessProxy_DidDestroyFrame = 1049
    , WebProcessProxy_DidDestroyUserGestureToken = 1050
    , WebProcessProxy_ShouldTerminate = 1051
    , WebProcessProxy_EnableSuddenTermination = 1052
    , WebProcessProxy_DisableSuddenTermination = 1053
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebProcessProxy_GetPlugins = 1054
#endif
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebProcessProxy_GetPluginProcessConnection = 1055
#endif
    , WebProcessProxy_GetNetworkProcessConnection = 1056
#if ENABLE(GPU_PROCESS)
    , WebProcessProxy_GetGPUProcessConnection = 1057
#endif
    , WebProcessProxy_DidExceedActiveMemoryLimit = 1058
    , WebProcessProxy_DidExceedInactiveMemoryLimit = 1059
    , WebProcessProxy_DidExceedCPULimit = 1060
    , WebProcessProxy_StopResponsivenessTimer = 1061
    , WebProcessProxy_DidReceiveMainThreadPing = 1062
    , WebProcessProxy_DidReceiveBackgroundResponsivenessPing = 1063
    , WebProcessProxy_MemoryPressureStatusChanged = 1064
    , WebProcessProxy_DidExceedInactiveMemoryLimitWhileActive = 1065
    , WebProcessProxy_DidCollectPrewarmInformation = 1066
#if PLATFORM(COCOA)
    , WebProcessProxy_CacheMediaMIMETypes = 1067
#endif
#if PLATFORM(MAC)
    , WebProcessProxy_RequestHighPerformanceGPU = 1068
#endif
#if PLATFORM(MAC)
    , WebProcessProxy_ReleaseHighPerformanceGPU = 1069
#endif
#if PLATFORM(MAC) && ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , WebProcessProxy_StartDisplayLink = 1070
#endif
#if PLATFORM(MAC) && ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , WebProcessProxy_StopDisplayLink = 1071
#endif
    , WebProcessProxy_AddPlugInAutoStartOriginHash = 1072
    , WebProcessProxy_PlugInDidReceiveUserInteraction = 1073
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebProcessProxy_SendMessageToWebContext = 1074
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebProcessProxy_SendMessageToWebContextWithReply = 1075
    , WebProcessProxy_SendMessageToWebContextWithReplyReply = 1076
#endif
    , WebProcessProxy_DidCreateSleepDisabler = 1077
    , WebProcessProxy_DidDestroySleepDisabler = 1078
    , WebAutomationSession_DidEvaluateJavaScriptFunction = 1079
    , WebAutomationSession_DidTakeScreenshot = 1080
    , DownloadProxy_DidStart = 1081
    , DownloadProxy_DidReceiveAuthenticationChallenge = 1082
    , DownloadProxy_WillSendRequest = 1083
    , DownloadProxy_DecideDestinationWithSuggestedFilenameAsync = 1084
    , DownloadProxy_DidReceiveResponse = 1085
    , DownloadProxy_DidReceiveData = 1086
    , DownloadProxy_DidCreateDestination = 1087
    , DownloadProxy_DidFinish = 1088
    , DownloadProxy_DidFail = 1089
    , DownloadProxy_DidCancel = 1090
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    , GPUProcessProxy_DidCreateContextForVisibilityPropagation = 1091
#endif
    , RemoteWebInspectorProxy_FrontendDidClose = 1092
    , RemoteWebInspectorProxy_Reopen = 1093
    , RemoteWebInspectorProxy_ResetState = 1094
    , RemoteWebInspectorProxy_BringToFront = 1095
    , RemoteWebInspectorProxy_Save = 1096
    , RemoteWebInspectorProxy_Append = 1097
    , RemoteWebInspectorProxy_SetForcedAppearance = 1098
    , RemoteWebInspectorProxy_SetSheetRect = 1099
    , RemoteWebInspectorProxy_StartWindowDrag = 1100
    , RemoteWebInspectorProxy_OpenInNewTab = 1101
    , RemoteWebInspectorProxy_ShowCertificate = 1102
    , RemoteWebInspectorProxy_SendMessageToBackend = 1103
    , WebInspectorProxy_OpenLocalInspectorFrontend = 1104
    , WebInspectorProxy_SetFrontendConnection = 1105
    , WebInspectorProxy_SendMessageToBackend = 1106
    , WebInspectorProxy_FrontendLoaded = 1107
    , WebInspectorProxy_DidClose = 1108
    , WebInspectorProxy_BringToFront = 1109
    , WebInspectorProxy_BringInspectedPageToFront = 1110
    , WebInspectorProxy_Reopen = 1111
    , WebInspectorProxy_ResetState = 1112
    , WebInspectorProxy_SetForcedAppearance = 1113
    , WebInspectorProxy_InspectedURLChanged = 1114
    , WebInspectorProxy_ShowCertificate = 1115
    , WebInspectorProxy_ElementSelectionChanged = 1116
    , WebInspectorProxy_TimelineRecordingChanged = 1117
    , WebInspectorProxy_SetDeveloperPreferenceOverride = 1118
    , WebInspectorProxy_Save = 1119
    , WebInspectorProxy_Append = 1120
    , WebInspectorProxy_AttachBottom = 1121
    , WebInspectorProxy_AttachRight = 1122
    , WebInspectorProxy_AttachLeft = 1123
    , WebInspectorProxy_Detach = 1124
    , WebInspectorProxy_AttachAvailabilityChanged = 1125
    , WebInspectorProxy_SetAttachedWindowHeight = 1126
    , WebInspectorProxy_SetAttachedWindowWidth = 1127
    , WebInspectorProxy_SetSheetRect = 1128
    , WebInspectorProxy_StartWindowDrag = 1129
    , NetworkProcessProxy_DidReceiveAuthenticationChallenge = 1130
    , NetworkProcessProxy_NegotiatedLegacyTLS = 1131
    , NetworkProcessProxy_DidNegotiateModernTLS = 1132
    , NetworkProcessProxy_DidFetchWebsiteData = 1133
    , NetworkProcessProxy_DidDeleteWebsiteData = 1134
    , NetworkProcessProxy_DidDeleteWebsiteDataForOrigins = 1135
    , NetworkProcessProxy_DidSyncAllCookies = 1136
    , NetworkProcessProxy_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply = 1137
    , NetworkProcessProxy_TerminateUnresponsiveServiceWorkerProcesses = 1138
    , NetworkProcessProxy_LogDiagnosticMessage = 1139
    , NetworkProcessProxy_LogDiagnosticMessageWithResult = 1140
    , NetworkProcessProxy_LogDiagnosticMessageWithValue = 1141
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_LogTestingEvent = 1142
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_NotifyResourceLoadStatisticsProcessed = 1143
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_NotifyWebsiteDataDeletionForRegistrableDomainsFinished = 1144
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_NotifyWebsiteDataScanForRegistrableDomainsFinished = 1145
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_NotifyResourceLoadStatisticsTelemetryFinished = 1146
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_RequestStorageAccessConfirm = 1147
    , NetworkProcessProxy_RequestStorageAccessConfirmReply = 1148
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomains = 1149
    , NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomainsReply = 1150
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_DidCommitCrossSiteLoadWithDataTransferFromPrevalentResource = 1151
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    , NetworkProcessProxy_ContentExtensionRules = 1152
#endif
    , NetworkProcessProxy_RetrieveCacheStorageParameters = 1153
    , NetworkProcessProxy_TerminateWebProcess = 1154
#if ENABLE(SERVICE_WORKER)
    , NetworkProcessProxy_EstablishWorkerContextConnectionToNetworkProcess = 1155
    , NetworkProcessProxy_EstablishWorkerContextConnectionToNetworkProcessReply = 1156
#endif
#if ENABLE(SERVICE_WORKER)
    , NetworkProcessProxy_WorkerContextConnectionNoLongerNeeded = 1157
#endif
#if ENABLE(SERVICE_WORKER)
    , NetworkProcessProxy_RegisterServiceWorkerClientProcess = 1158
#endif
#if ENABLE(SERVICE_WORKER)
    , NetworkProcessProxy_UnregisterServiceWorkerClientProcess = 1159
#endif
    , NetworkProcessProxy_SetWebProcessHasUploads = 1160
    , NetworkProcessProxy_GetAppBoundDomains = 1161
    , NetworkProcessProxy_GetAppBoundDomainsReply = 1162
    , NetworkProcessProxy_RequestStorageSpace = 1163
    , NetworkProcessProxy_RequestStorageSpaceReply = 1164
    , NetworkProcessProxy_ResourceLoadDidSendRequest = 1165
    , NetworkProcessProxy_ResourceLoadDidPerformHTTPRedirection = 1166
    , NetworkProcessProxy_ResourceLoadDidReceiveChallenge = 1167
    , NetworkProcessProxy_ResourceLoadDidReceiveResponse = 1168
    , NetworkProcessProxy_ResourceLoadDidCompleteWithError = 1169
    , PluginProcessProxy_DidCreateWebProcessConnection = 1170
    , PluginProcessProxy_DidGetSitesWithData = 1171
    , PluginProcessProxy_DidDeleteWebsiteData = 1172
    , PluginProcessProxy_DidDeleteWebsiteDataForHostNames = 1173
#if PLATFORM(COCOA)
    , PluginProcessProxy_SetModalWindowIsShowing = 1174
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_SetFullscreenWindowIsShowing = 1175
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_LaunchProcess = 1176
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_LaunchApplicationAtURL = 1177
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_OpenURL = 1178
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_OpenFile = 1179
#endif
    , WebUserContentControllerProxy_DidPostMessage = 1180
    , WebUserContentControllerProxy_DidPostMessageReply = 1181
    , WebProcess_InitializeWebProcess = 1182
    , WebProcess_SetWebsiteDataStoreParameters = 1183
    , WebProcess_CreateWebPage = 1184
    , WebProcess_PrewarmGlobally = 1185
    , WebProcess_PrewarmWithDomainInformation = 1186
    , WebProcess_SetCacheModel = 1187
    , WebProcess_RegisterURLSchemeAsEmptyDocument = 1188
    , WebProcess_RegisterURLSchemeAsSecure = 1189
    , WebProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy = 1190
    , WebProcess_SetDomainRelaxationForbiddenForURLScheme = 1191
    , WebProcess_RegisterURLSchemeAsLocal = 1192
    , WebProcess_RegisterURLSchemeAsNoAccess = 1193
    , WebProcess_RegisterURLSchemeAsDisplayIsolated = 1194
    , WebProcess_RegisterURLSchemeAsCORSEnabled = 1195
    , WebProcess_RegisterURLSchemeAsCachePartitioned = 1196
    , WebProcess_RegisterURLSchemeAsCanDisplayOnlyIfCanRequest = 1197
    , WebProcess_SetDefaultRequestTimeoutInterval = 1198
    , WebProcess_SetAlwaysUsesComplexTextCodePath = 1199
    , WebProcess_SetShouldUseFontSmoothing = 1200
    , WebProcess_SetResourceLoadStatisticsEnabled = 1201
    , WebProcess_ClearResourceLoadStatistics = 1202
    , WebProcess_UserPreferredLanguagesChanged = 1203
    , WebProcess_FullKeyboardAccessModeChanged = 1204
    , WebProcess_DidAddPlugInAutoStartOriginHash = 1205
    , WebProcess_ResetPlugInAutoStartOriginHashes = 1206
    , WebProcess_SetPluginLoadClientPolicy = 1207
    , WebProcess_ResetPluginLoadClientPolicies = 1208
    , WebProcess_ClearPluginClientPolicies = 1209
    , WebProcess_RefreshPlugins = 1210
    , WebProcess_StartMemorySampler = 1211
    , WebProcess_StopMemorySampler = 1212
    , WebProcess_SetTextCheckerState = 1213
    , WebProcess_SetEnhancedAccessibility = 1214
    , WebProcess_GarbageCollectJavaScriptObjects = 1215
    , WebProcess_SetJavaScriptGarbageCollectorTimerEnabled = 1216
    , WebProcess_SetInjectedBundleParameter = 1217
    , WebProcess_SetInjectedBundleParameters = 1218
    , WebProcess_HandleInjectedBundleMessage = 1219
    , WebProcess_FetchWebsiteData = 1220
    , WebProcess_FetchWebsiteDataReply = 1221
    , WebProcess_DeleteWebsiteData = 1222
    , WebProcess_DeleteWebsiteDataReply = 1223
    , WebProcess_DeleteWebsiteDataForOrigins = 1224
    , WebProcess_DeleteWebsiteDataForOriginsReply = 1225
    , WebProcess_SetHiddenPageDOMTimerThrottlingIncreaseLimit = 1226
#if PLATFORM(COCOA)
    , WebProcess_SetQOS = 1227
#endif
    , WebProcess_SetMemoryCacheDisabled = 1228
#if ENABLE(SERVICE_CONTROLS)
    , WebProcess_SetEnabledServices = 1229
#endif
    , WebProcess_EnsureAutomationSessionProxy = 1230
    , WebProcess_DestroyAutomationSessionProxy = 1231
    , WebProcess_PrepareToSuspend = 1232
    , WebProcess_PrepareToSuspendReply = 1233
    , WebProcess_ProcessDidResume = 1234
    , WebProcess_MainThreadPing = 1235
    , WebProcess_BackgroundResponsivenessPing = 1236
#if ENABLE(GAMEPAD)
    , WebProcess_SetInitialGamepads = 1237
#endif
#if ENABLE(GAMEPAD)
    , WebProcess_GamepadConnected = 1238
#endif
#if ENABLE(GAMEPAD)
    , WebProcess_GamepadDisconnected = 1239
#endif
#if ENABLE(SERVICE_WORKER)
    , WebProcess_EstablishWorkerContextConnectionToNetworkProcess = 1240
    , WebProcess_EstablishWorkerContextConnectionToNetworkProcessReply = 1241
#endif
    , WebProcess_SetHasSuspendedPageProxy = 1242
    , WebProcess_SetIsInProcessCache = 1243
    , WebProcess_MarkIsNoLongerPrewarmed = 1244
    , WebProcess_GetActivePagesOriginsForTesting = 1245
    , WebProcess_GetActivePagesOriginsForTestingReply = 1246
#if PLATFORM(COCOA)
    , WebProcess_SetScreenProperties = 1247
#endif
#if PLATFORM(MAC) && ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , WebProcess_ScrollerStylePreferenceChanged = 1248
#endif
#if PLATFORM(MAC) && ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , WebProcess_DisplayConfigurationChanged = 1249
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    , WebProcess_BacklightLevelDidChange = 1250
#endif
    , WebProcess_IsJITEnabled = 1251
    , WebProcess_IsJITEnabledReply = 1252
#if PLATFORM(COCOA)
    , WebProcess_SetMediaMIMETypes = 1253
#endif
#if (PLATFORM(COCOA) && ENABLE(REMOTE_INSPECTOR))
    , WebProcess_EnableRemoteWebInspector = 1254
#endif
#if ENABLE(MEDIA_STREAM)
    , WebProcess_AddMockMediaDevice = 1255
#endif
#if ENABLE(MEDIA_STREAM)
    , WebProcess_ClearMockMediaDevices = 1256
#endif
#if ENABLE(MEDIA_STREAM)
    , WebProcess_RemoveMockMediaDevice = 1257
#endif
#if ENABLE(MEDIA_STREAM)
    , WebProcess_ResetMockMediaDevices = 1258
#endif
#if (ENABLE(MEDIA_STREAM) && ENABLE(SANDBOX_EXTENSIONS))
    , WebProcess_GrantUserMediaDeviceSandboxExtensions = 1259
#endif
#if (ENABLE(MEDIA_STREAM) && ENABLE(SANDBOX_EXTENSIONS))
    , WebProcess_RevokeUserMediaDeviceSandboxExtensions = 1260
#endif
    , WebProcess_ClearCurrentModifierStateForTesting = 1261
    , WebProcess_SetBackForwardCacheCapacity = 1262
    , WebProcess_ClearCachedPage = 1263
    , WebProcess_ClearCachedPageReply = 1264
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebProcess_SendMessageToWebExtension = 1265
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebProcess_SeedResourceLoadStatisticsForTesting = 1266
    , WebProcess_SeedResourceLoadStatisticsForTestingReply = 1267
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebProcess_SetThirdPartyCookieBlockingMode = 1268
    , WebProcess_SetThirdPartyCookieBlockingModeReply = 1269
#endif
#if PLATFORM(IOS)
    , WebProcess_GrantAccessToAssetServices = 1270
#endif
#if PLATFORM(IOS)
    , WebProcess_RevokeAccessToAssetServices = 1271
#endif
#if PLATFORM(COCOA)
    , WebProcess_UnblockServicesRequiredByAccessibility = 1272
#endif
#if (PLATFORM(COCOA) && ENABLE(CFPREFS_DIRECT_MODE))
    , WebProcess_NotifyPreferencesChanged = 1273
#endif
#if (PLATFORM(COCOA) && ENABLE(CFPREFS_DIRECT_MODE))
    , WebProcess_UnblockPreferenceService = 1274
#endif
#if PLATFORM(GTK) && !USE(GTK4)
    , WebProcess_SetUseSystemAppearanceForScrollbars = 1275
#endif
    , WebAutomationSessionProxy_EvaluateJavaScriptFunction = 1276
    , WebAutomationSessionProxy_ResolveChildFrameWithOrdinal = 1277
    , WebAutomationSessionProxy_ResolveChildFrameWithOrdinalReply = 1278
    , WebAutomationSessionProxy_ResolveChildFrameWithNodeHandle = 1279
    , WebAutomationSessionProxy_ResolveChildFrameWithNodeHandleReply = 1280
    , WebAutomationSessionProxy_ResolveChildFrameWithName = 1281
    , WebAutomationSessionProxy_ResolveChildFrameWithNameReply = 1282
    , WebAutomationSessionProxy_ResolveParentFrame = 1283
    , WebAutomationSessionProxy_ResolveParentFrameReply = 1284
    , WebAutomationSessionProxy_FocusFrame = 1285
    , WebAutomationSessionProxy_ComputeElementLayout = 1286
    , WebAutomationSessionProxy_ComputeElementLayoutReply = 1287
    , WebAutomationSessionProxy_SelectOptionElement = 1288
    , WebAutomationSessionProxy_SelectOptionElementReply = 1289
    , WebAutomationSessionProxy_SetFilesForInputFileUpload = 1290
    , WebAutomationSessionProxy_SetFilesForInputFileUploadReply = 1291
    , WebAutomationSessionProxy_TakeScreenshot = 1292
    , WebAutomationSessionProxy_SnapshotRectForScreenshot = 1293
    , WebAutomationSessionProxy_SnapshotRectForScreenshotReply = 1294
    , WebAutomationSessionProxy_GetCookiesForFrame = 1295
    , WebAutomationSessionProxy_GetCookiesForFrameReply = 1296
    , WebAutomationSessionProxy_DeleteCookie = 1297
    , WebAutomationSessionProxy_DeleteCookieReply = 1298
    , WebIDBConnectionToServer_DidDeleteDatabase = 1299
    , WebIDBConnectionToServer_DidOpenDatabase = 1300
    , WebIDBConnectionToServer_DidAbortTransaction = 1301
    , WebIDBConnectionToServer_DidCommitTransaction = 1302
    , WebIDBConnectionToServer_DidCreateObjectStore = 1303
    , WebIDBConnectionToServer_DidDeleteObjectStore = 1304
    , WebIDBConnectionToServer_DidRenameObjectStore = 1305
    , WebIDBConnectionToServer_DidClearObjectStore = 1306
    , WebIDBConnectionToServer_DidCreateIndex = 1307
    , WebIDBConnectionToServer_DidDeleteIndex = 1308
    , WebIDBConnectionToServer_DidRenameIndex = 1309
    , WebIDBConnectionToServer_DidPutOrAdd = 1310
    , WebIDBConnectionToServer_DidGetRecord = 1311
    , WebIDBConnectionToServer_DidGetAllRecords = 1312
    , WebIDBConnectionToServer_DidGetCount = 1313
    , WebIDBConnectionToServer_DidDeleteRecord = 1314
    , WebIDBConnectionToServer_DidOpenCursor = 1315
    , WebIDBConnectionToServer_DidIterateCursor = 1316
    , WebIDBConnectionToServer_FireVersionChangeEvent = 1317
    , WebIDBConnectionToServer_DidStartTransaction = 1318
    , WebIDBConnectionToServer_DidCloseFromServer = 1319
    , WebIDBConnectionToServer_NotifyOpenDBRequestBlocked = 1320
    , WebIDBConnectionToServer_DidGetAllDatabaseNames = 1321
    , WebFullScreenManager_RequestExitFullScreen = 1322
    , WebFullScreenManager_WillEnterFullScreen = 1323
    , WebFullScreenManager_DidEnterFullScreen = 1324
    , WebFullScreenManager_WillExitFullScreen = 1325
    , WebFullScreenManager_DidExitFullScreen = 1326
    , WebFullScreenManager_SetAnimatingFullScreen = 1327
    , WebFullScreenManager_SaveScrollPosition = 1328
    , WebFullScreenManager_RestoreScrollPosition = 1329
    , WebFullScreenManager_SetFullscreenInsets = 1330
    , WebFullScreenManager_SetFullscreenAutoHideDuration = 1331
    , WebFullScreenManager_SetFullscreenControlsHidden = 1332
    , GPUProcessConnection_DidReceiveRemoteCommand = 1333
    , RemoteRenderingBackend_CreateImageBufferBackend = 1334
    , RemoteRenderingBackend_CommitImageBufferFlushContext = 1335
    , MediaPlayerPrivateRemote_NetworkStateChanged = 1336
    , MediaPlayerPrivateRemote_ReadyStateChanged = 1337
    , MediaPlayerPrivateRemote_FirstVideoFrameAvailable = 1338
    , MediaPlayerPrivateRemote_VolumeChanged = 1339
    , MediaPlayerPrivateRemote_MuteChanged = 1340
    , MediaPlayerPrivateRemote_TimeChanged = 1341
    , MediaPlayerPrivateRemote_DurationChanged = 1342
    , MediaPlayerPrivateRemote_RateChanged = 1343
    , MediaPlayerPrivateRemote_PlaybackStateChanged = 1344
    , MediaPlayerPrivateRemote_EngineFailedToLoad = 1345
    , MediaPlayerPrivateRemote_UpdateCachedState = 1346
    , MediaPlayerPrivateRemote_CharacteristicChanged = 1347
    , MediaPlayerPrivateRemote_SizeChanged = 1348
    , MediaPlayerPrivateRemote_AddRemoteAudioTrack = 1349
    , MediaPlayerPrivateRemote_RemoveRemoteAudioTrack = 1350
    , MediaPlayerPrivateRemote_RemoteAudioTrackConfigurationChanged = 1351
    , MediaPlayerPrivateRemote_AddRemoteTextTrack = 1352
    , MediaPlayerPrivateRemote_RemoveRemoteTextTrack = 1353
    , MediaPlayerPrivateRemote_RemoteTextTrackConfigurationChanged = 1354
    , MediaPlayerPrivateRemote_ParseWebVTTFileHeader = 1355
    , MediaPlayerPrivateRemote_ParseWebVTTCueData = 1356
    , MediaPlayerPrivateRemote_ParseWebVTTCueDataStruct = 1357
    , MediaPlayerPrivateRemote_AddDataCue = 1358
#if ENABLE(DATACUE_VALUE)
    , MediaPlayerPrivateRemote_AddDataCueWithType = 1359
#endif
#if ENABLE(DATACUE_VALUE)
    , MediaPlayerPrivateRemote_UpdateDataCue = 1360
#endif
#if ENABLE(DATACUE_VALUE)
    , MediaPlayerPrivateRemote_RemoveDataCue = 1361
#endif
    , MediaPlayerPrivateRemote_AddGenericCue = 1362
    , MediaPlayerPrivateRemote_UpdateGenericCue = 1363
    , MediaPlayerPrivateRemote_RemoveGenericCue = 1364
    , MediaPlayerPrivateRemote_AddRemoteVideoTrack = 1365
    , MediaPlayerPrivateRemote_RemoveRemoteVideoTrack = 1366
    , MediaPlayerPrivateRemote_RemoteVideoTrackConfigurationChanged = 1367
    , MediaPlayerPrivateRemote_RequestResource = 1368
    , MediaPlayerPrivateRemote_RequestResourceReply = 1369
    , MediaPlayerPrivateRemote_RemoveResource = 1370
    , MediaPlayerPrivateRemote_ResourceNotSupported = 1371
    , MediaPlayerPrivateRemote_EngineUpdated = 1372
    , MediaPlayerPrivateRemote_ActiveSourceBuffersChanged = 1373
#if ENABLE(ENCRYPTED_MEDIA)
    , MediaPlayerPrivateRemote_WaitingForKeyChanged = 1374
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    , MediaPlayerPrivateRemote_InitializationDataEncountered = 1375
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    , MediaPlayerPrivateRemote_MediaPlayerKeyNeeded = 1376
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    , MediaPlayerPrivateRemote_CurrentPlaybackTargetIsWirelessChanged = 1377
#endif
    , RemoteAudioDestinationProxy_RenderBuffer = 1378
    , RemoteAudioDestinationProxy_RenderBufferReply = 1379
    , RemoteAudioDestinationProxy_DidChangeIsPlaying = 1380
    , RemoteAudioSession_ConfigurationChanged = 1381
    , RemoteAudioSession_BeginInterruption = 1382
    , RemoteAudioSession_EndInterruption = 1383
    , RemoteCDMInstanceSession_UpdateKeyStatuses = 1384
    , RemoteCDMInstanceSession_SendMessage = 1385
    , RemoteCDMInstanceSession_SessionIdChanged = 1386
    , RemoteLegacyCDMSession_SendMessage = 1387
    , RemoteLegacyCDMSession_SendError = 1388
    , LibWebRTCCodecs_FailedDecoding = 1389
    , LibWebRTCCodecs_CompletedDecoding = 1390
    , LibWebRTCCodecs_CompletedEncoding = 1391
    , SampleBufferDisplayLayer_SetDidFail = 1392
    , WebGeolocationManager_DidChangePosition = 1393
    , WebGeolocationManager_DidFailToDeterminePosition = 1394
#if PLATFORM(IOS_FAMILY)
    , WebGeolocationManager_ResetPermissions = 1395
#endif
    , RemoteWebInspectorUI_Initialize = 1396
    , RemoteWebInspectorUI_UpdateFindString = 1397
#if ENABLE(INSPECTOR_TELEMETRY)
    , RemoteWebInspectorUI_SetDiagnosticLoggingAvailable = 1398
#endif
    , RemoteWebInspectorUI_DidSave = 1399
    , RemoteWebInspectorUI_DidAppend = 1400
    , RemoteWebInspectorUI_SendMessageToFrontend = 1401
    , WebInspector_Show = 1402
    , WebInspector_Close = 1403
    , WebInspector_SetAttached = 1404
    , WebInspector_ShowConsole = 1405
    , WebInspector_ShowResources = 1406
    , WebInspector_ShowMainResourceForFrame = 1407
    , WebInspector_OpenInNewTab = 1408
    , WebInspector_StartPageProfiling = 1409
    , WebInspector_StopPageProfiling = 1410
    , WebInspector_StartElementSelection = 1411
    , WebInspector_StopElementSelection = 1412
    , WebInspector_SetFrontendConnection = 1413
    , WebInspectorInterruptDispatcher_NotifyNeedDebuggerBreak = 1414
    , WebInspectorUI_EstablishConnection = 1415
    , WebInspectorUI_UpdateConnection = 1416
    , WebInspectorUI_AttachedBottom = 1417
    , WebInspectorUI_AttachedRight = 1418
    , WebInspectorUI_AttachedLeft = 1419
    , WebInspectorUI_Detached = 1420
    , WebInspectorUI_SetDockingUnavailable = 1421
    , WebInspectorUI_SetIsVisible = 1422
    , WebInspectorUI_UpdateFindString = 1423
#if ENABLE(INSPECTOR_TELEMETRY)
    , WebInspectorUI_SetDiagnosticLoggingAvailable = 1424
#endif
    , WebInspectorUI_ShowConsole = 1425
    , WebInspectorUI_ShowResources = 1426
    , WebInspectorUI_ShowMainResourceForFrame = 1427
    , WebInspectorUI_StartPageProfiling = 1428
    , WebInspectorUI_StopPageProfiling = 1429
    , WebInspectorUI_StartElementSelection = 1430
    , WebInspectorUI_StopElementSelection = 1431
    , WebInspectorUI_DidSave = 1432
    , WebInspectorUI_DidAppend = 1433
    , WebInspectorUI_SendMessageToFrontend = 1434
    , LibWebRTCNetwork_SignalReadPacket = 1435
    , LibWebRTCNetwork_SignalSentPacket = 1436
    , LibWebRTCNetwork_SignalAddressReady = 1437
    , LibWebRTCNetwork_SignalConnect = 1438
    , LibWebRTCNetwork_SignalClose = 1439
    , LibWebRTCNetwork_SignalNewConnection = 1440
    , WebMDNSRegister_FinishedRegisteringMDNSName = 1441
    , WebRTCMonitor_NetworksChanged = 1442
    , WebRTCResolver_SetResolvedAddress = 1443
    , WebRTCResolver_ResolvedAddressError = 1444
#if ENABLE(SHAREABLE_RESOURCE)
    , NetworkProcessConnection_DidCacheResource = 1445
#endif
    , NetworkProcessConnection_DidFinishPingLoad = 1446
    , NetworkProcessConnection_DidFinishPreconnection = 1447
    , NetworkProcessConnection_SetOnLineState = 1448
    , NetworkProcessConnection_CookieAcceptPolicyChanged = 1449
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    , NetworkProcessConnection_CookiesAdded = 1450
#endif
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    , NetworkProcessConnection_CookiesDeleted = 1451
#endif
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    , NetworkProcessConnection_AllCookiesDeleted = 1452
#endif
    , NetworkProcessConnection_CheckProcessLocalPortForActivity = 1453
    , NetworkProcessConnection_CheckProcessLocalPortForActivityReply = 1454
    , NetworkProcessConnection_MessagesAvailableForPort = 1455
    , NetworkProcessConnection_BroadcastConsoleMessage = 1456
    , WebResourceLoader_WillSendRequest = 1457
    , WebResourceLoader_DidSendData = 1458
    , WebResourceLoader_DidReceiveResponse = 1459
    , WebResourceLoader_DidReceiveData = 1460
    , WebResourceLoader_DidReceiveSharedBuffer = 1461
    , WebResourceLoader_DidFinishResourceLoad = 1462
    , WebResourceLoader_DidFailResourceLoad = 1463
    , WebResourceLoader_DidFailServiceWorkerLoad = 1464
    , WebResourceLoader_ServiceWorkerDidNotHandle = 1465
    , WebResourceLoader_DidBlockAuthenticationChallenge = 1466
    , WebResourceLoader_StopLoadingAfterXFrameOptionsOrContentSecurityPolicyDenied = 1467
#if ENABLE(SHAREABLE_RESOURCE)
    , WebResourceLoader_DidReceiveResource = 1468
#endif
    , WebSocketChannel_DidConnect = 1469
    , WebSocketChannel_DidClose = 1470
    , WebSocketChannel_DidReceiveText = 1471
    , WebSocketChannel_DidReceiveBinaryData = 1472
    , WebSocketChannel_DidReceiveMessageError = 1473
    , WebSocketChannel_DidSendHandshakeRequest = 1474
    , WebSocketChannel_DidReceiveHandshakeResponse = 1475
    , WebSocketStream_DidOpenSocketStream = 1476
    , WebSocketStream_DidCloseSocketStream = 1477
    , WebSocketStream_DidReceiveSocketStreamData = 1478
    , WebSocketStream_DidFailToReceiveSocketStreamData = 1479
    , WebSocketStream_DidUpdateBufferedAmount = 1480
    , WebSocketStream_DidFailSocketStream = 1481
    , WebSocketStream_DidSendData = 1482
    , WebSocketStream_DidSendHandshake = 1483
    , WebNotificationManager_DidShowNotification = 1484
    , WebNotificationManager_DidClickNotification = 1485
    , WebNotificationManager_DidCloseNotifications = 1486
    , WebNotificationManager_DidUpdateNotificationDecision = 1487
    , WebNotificationManager_DidRemoveNotificationDecisions = 1488
    , PluginProcessConnection_SetException = 1489
    , PluginProcessConnectionManager_PluginProcessCrashed = 1490
    , PluginProxy_LoadURL = 1491
    , PluginProxy_Update = 1492
    , PluginProxy_ProxiesForURL = 1493
    , PluginProxy_CookiesForURL = 1494
    , PluginProxy_SetCookiesForURL = 1495
    , PluginProxy_GetAuthenticationInfo = 1496
    , PluginProxy_GetPluginElementNPObject = 1497
    , PluginProxy_Evaluate = 1498
    , PluginProxy_CancelStreamLoad = 1499
    , PluginProxy_ContinueStreamLoad = 1500
    , PluginProxy_CancelManualStreamLoad = 1501
    , PluginProxy_SetStatusbarText = 1502
#if PLATFORM(COCOA)
    , PluginProxy_PluginFocusOrWindowFocusChanged = 1503
#endif
#if PLATFORM(COCOA)
    , PluginProxy_SetComplexTextInputState = 1504
#endif
#if PLATFORM(COCOA)
    , PluginProxy_SetLayerHostingContextID = 1505
#endif
#if PLATFORM(X11)
    , PluginProxy_CreatePluginContainer = 1506
#endif
#if PLATFORM(X11)
    , PluginProxy_WindowedPluginGeometryDidChange = 1507
#endif
#if PLATFORM(X11)
    , PluginProxy_WindowedPluginVisibilityDidChange = 1508
#endif
    , PluginProxy_DidCreatePlugin = 1509
    , PluginProxy_DidFailToCreatePlugin = 1510
    , PluginProxy_SetPluginIsPlayingAudio = 1511
    , WebSWClientConnection_JobRejectedInServer = 1512
    , WebSWClientConnection_RegistrationJobResolvedInServer = 1513
    , WebSWClientConnection_StartScriptFetchForServer = 1514
    , WebSWClientConnection_UpdateRegistrationState = 1515
    , WebSWClientConnection_UpdateWorkerState = 1516
    , WebSWClientConnection_FireUpdateFoundEvent = 1517
    , WebSWClientConnection_SetRegistrationLastUpdateTime = 1518
    , WebSWClientConnection_SetRegistrationUpdateViaCache = 1519
    , WebSWClientConnection_NotifyClientsOfControllerChange = 1520
    , WebSWClientConnection_SetSWOriginTableIsImported = 1521
    , WebSWClientConnection_SetSWOriginTableSharedMemory = 1522
    , WebSWClientConnection_PostMessageToServiceWorkerClient = 1523
    , WebSWClientConnection_DidMatchRegistration = 1524
    , WebSWClientConnection_DidGetRegistrations = 1525
    , WebSWClientConnection_RegistrationReady = 1526
    , WebSWClientConnection_SetDocumentIsControlled = 1527
    , WebSWClientConnection_SetDocumentIsControlledReply = 1528
    , WebSWContextManagerConnection_InstallServiceWorker = 1529
    , WebSWContextManagerConnection_StartFetch = 1530
    , WebSWContextManagerConnection_CancelFetch = 1531
    , WebSWContextManagerConnection_ContinueDidReceiveFetchResponse = 1532
    , WebSWContextManagerConnection_PostMessageToServiceWorker = 1533
    , WebSWContextManagerConnection_FireInstallEvent = 1534
    , WebSWContextManagerConnection_FireActivateEvent = 1535
    , WebSWContextManagerConnection_TerminateWorker = 1536
    , WebSWContextManagerConnection_FindClientByIdentifierCompleted = 1537
    , WebSWContextManagerConnection_MatchAllCompleted = 1538
    , WebSWContextManagerConnection_SetUserAgent = 1539
    , WebSWContextManagerConnection_UpdatePreferencesStore = 1540
    , WebSWContextManagerConnection_Close = 1541
    , WebSWContextManagerConnection_SetThrottleState = 1542
    , WebUserContentController_AddContentWorlds = 1543
    , WebUserContentController_RemoveContentWorlds = 1544
    , WebUserContentController_AddUserScripts = 1545
    , WebUserContentController_RemoveUserScript = 1546
    , WebUserContentController_RemoveAllUserScripts = 1547
    , WebUserContentController_AddUserStyleSheets = 1548
    , WebUserContentController_RemoveUserStyleSheet = 1549
    , WebUserContentController_RemoveAllUserStyleSheets = 1550
    , WebUserContentController_AddUserScriptMessageHandlers = 1551
    , WebUserContentController_RemoveUserScriptMessageHandler = 1552
    , WebUserContentController_RemoveAllUserScriptMessageHandlersForWorlds = 1553
    , WebUserContentController_RemoveAllUserScriptMessageHandlers = 1554
#if ENABLE(CONTENT_EXTENSIONS)
    , WebUserContentController_AddContentRuleLists = 1555
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    , WebUserContentController_RemoveContentRuleList = 1556
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    , WebUserContentController_RemoveAllContentRuleLists = 1557
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    , DrawingArea_UpdateBackingStoreState = 1558
#endif
    , DrawingArea_DidUpdate = 1559
#if PLATFORM(COCOA)
    , DrawingArea_UpdateGeometry = 1560
#endif
#if PLATFORM(COCOA)
    , DrawingArea_SetDeviceScaleFactor = 1561
#endif
#if PLATFORM(COCOA)
    , DrawingArea_SetColorSpace = 1562
#endif
#if PLATFORM(COCOA)
    , DrawingArea_SetViewExposedRect = 1563
#endif
#if PLATFORM(COCOA)
    , DrawingArea_AdjustTransientZoom = 1564
#endif
#if PLATFORM(COCOA)
    , DrawingArea_CommitTransientZoom = 1565
#endif
#if PLATFORM(COCOA)
    , DrawingArea_AcceleratedAnimationDidStart = 1566
#endif
#if PLATFORM(COCOA)
    , DrawingArea_AcceleratedAnimationDidEnd = 1567
#endif
#if PLATFORM(COCOA)
    , DrawingArea_AddTransactionCallbackID = 1568
#endif
    , EventDispatcher_WheelEvent = 1569
#if ENABLE(IOS_TOUCH_EVENTS)
    , EventDispatcher_TouchEvent = 1570
#endif
#if ENABLE(MAC_GESTURE_EVENTS)
    , EventDispatcher_GestureEvent = 1571
#endif
#if ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , EventDispatcher_DisplayWasRefreshed = 1572
#endif
    , VisitedLinkTableController_SetVisitedLinkTable = 1573
    , VisitedLinkTableController_VisitedLinkStateChanged = 1574
    , VisitedLinkTableController_AllVisitedLinkStateChanged = 1575
    , VisitedLinkTableController_RemoveAllVisitedLinks = 1576
    , WebPage_SetInitialFocus = 1577
    , WebPage_SetInitialFocusReply = 1578
    , WebPage_SetActivityState = 1579
    , WebPage_SetLayerHostingMode = 1580
    , WebPage_SetBackgroundColor = 1581
    , WebPage_AddConsoleMessage = 1582
    , WebPage_SendCSPViolationReport = 1583
    , WebPage_EnqueueSecurityPolicyViolationEvent = 1584
    , WebPage_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply = 1585
#if PLATFORM(COCOA)
    , WebPage_SetTopContentInsetFenced = 1586
#endif
    , WebPage_SetTopContentInset = 1587
    , WebPage_SetUnderlayColor = 1588
    , WebPage_ViewWillStartLiveResize = 1589
    , WebPage_ViewWillEndLiveResize = 1590
    , WebPage_ExecuteEditCommandWithCallback = 1591
    , WebPage_ExecuteEditCommandWithCallbackReply = 1592
    , WebPage_KeyEvent = 1593
    , WebPage_MouseEvent = 1594
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetViewportConfigurationViewLayoutSize = 1595
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetMaximumUnobscuredSize = 1596
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetDeviceOrientation = 1597
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetOverrideViewportArguments = 1598
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_DynamicViewportSizeUpdate = 1599
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HandleTap = 1600
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_PotentialTapAtPosition = 1601
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_CommitPotentialTap = 1602
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_CancelPotentialTap = 1603
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_TapHighlightAtPosition = 1604
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_DidRecognizeLongPress = 1605
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HandleDoubleTapForDoubleClickAtPoint = 1606
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_InspectorNodeSearchMovedToPosition = 1607
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_InspectorNodeSearchEndedAtPosition = 1608
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_BlurFocusedElement = 1609
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectWithGesture = 1610
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_UpdateSelectionWithTouches = 1611
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectWithTwoTouches = 1612
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ExtendSelection = 1613
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectWordBackward = 1614
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_MoveSelectionByOffset = 1615
    , WebPage_MoveSelectionByOffsetReply = 1616
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectTextWithGranularityAtPoint = 1617
    , WebPage_SelectTextWithGranularityAtPointReply = 1618
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectPositionAtBoundaryWithDirection = 1619
    , WebPage_SelectPositionAtBoundaryWithDirectionReply = 1620
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_MoveSelectionAtBoundaryWithDirection = 1621
    , WebPage_MoveSelectionAtBoundaryWithDirectionReply = 1622
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectPositionAtPoint = 1623
    , WebPage_SelectPositionAtPointReply = 1624
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_BeginSelectionInDirection = 1625
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_UpdateSelectionWithExtentPoint = 1626
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_UpdateSelectionWithExtentPointAndBoundary = 1627
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestDictationContext = 1628
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ReplaceDictatedText = 1629
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ReplaceSelectedText = 1630
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestAutocorrectionData = 1631
    , WebPage_RequestAutocorrectionDataReply = 1632
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplyAutocorrection = 1633
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SyncApplyAutocorrection = 1634
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestAutocorrectionContext = 1635
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestEvasionRectsAboveSelection = 1636
    , WebPage_RequestEvasionRectsAboveSelectionReply = 1637
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GetPositionInformation = 1638
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestPositionInformation = 1639
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_StartInteractionWithElementContextOrPosition = 1640
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_StopInteraction = 1641
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_PerformActionOnElement = 1642
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_FocusNextFocusedElement = 1643
    , WebPage_FocusNextFocusedElementReply = 1644
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetFocusedElementValue = 1645
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_AutofillLoginCredentials = 1646
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetFocusedElementValueAsNumber = 1647
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetFocusedElementSelectedIndex = 1648
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationWillResignActive = 1649
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationDidEnterBackground = 1650
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationDidFinishSnapshottingAfterEnteringBackground = 1651
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationWillEnterForeground = 1652
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationDidBecomeActive = 1653
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationDidEnterBackgroundForMedia = 1654
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationWillEnterForegroundForMedia = 1655
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ContentSizeCategoryDidChange = 1656
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GetSelectionContext = 1657
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetAllowsMediaDocumentInlinePlayback = 1658
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HandleTwoFingerTapAtPoint = 1659
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HandleStylusSingleTapAtPoint = 1660
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetForceAlwaysUserScalable = 1661
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GetRectsForGranularityWithSelectionOffset = 1662
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GetRectsAtSelectionOffsetWithText = 1663
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_StoreSelectionForAccessibility = 1664
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_StartAutoscrollAtPosition = 1665
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_CancelAutoscroll = 1666
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestFocusedElementInformation = 1667
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HardwareKeyboardAvailabilityChanged = 1668
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetIsShowingInputViewForFocusedElement = 1669
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_UpdateSelectionWithDelta = 1670
    , WebPage_UpdateSelectionWithDeltaReply = 1671
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestDocumentEditingContext = 1672
    , WebPage_RequestDocumentEditingContextReply = 1673
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GenerateSyntheticEditingCommand = 1674
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetShouldRevealCurrentSelectionAfterInsertion = 1675
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_InsertTextPlaceholder = 1676
    , WebPage_InsertTextPlaceholderReply = 1677
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RemoveTextPlaceholder = 1678
    , WebPage_RemoveTextPlaceholderReply = 1679
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_TextInputContextsInRect = 1680
    , WebPage_TextInputContextsInRectReply = 1681
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_FocusTextInputContextAndPlaceCaret = 1682
    , WebPage_FocusTextInputContextAndPlaceCaretReply = 1683
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ClearServiceWorkerEntitlementOverride = 1684
    , WebPage_ClearServiceWorkerEntitlementOverrideReply = 1685
#endif
    , WebPage_SetControlledByAutomation = 1686
    , WebPage_ConnectInspector = 1687
    , WebPage_DisconnectInspector = 1688
    , WebPage_SendMessageToTargetBackend = 1689
#if ENABLE(REMOTE_INSPECTOR)
    , WebPage_SetIndicating = 1690
#endif
#if ENABLE(IOS_TOUCH_EVENTS)
    , WebPage_ResetPotentialTapSecurityOrigin = 1691
#endif
#if ENABLE(IOS_TOUCH_EVENTS)
    , WebPage_TouchEventSync = 1692
#endif
#if !ENABLE(IOS_TOUCH_EVENTS) && ENABLE(TOUCH_EVENTS)
    , WebPage_TouchEvent = 1693
#endif
    , WebPage_CancelPointer = 1694
    , WebPage_TouchWithIdentifierWasRemoved = 1695
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPage_DidEndColorPicker = 1696
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPage_DidChooseColor = 1697
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPage_DidSelectDataListOption = 1698
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPage_DidCloseSuggestions = 1699
#endif
#if ENABLE(CONTEXT_MENUS)
    , WebPage_ContextMenuHidden = 1700
#endif
#if ENABLE(CONTEXT_MENUS)
    , WebPage_ContextMenuForKeyEvent = 1701
#endif
    , WebPage_ScrollBy = 1702
    , WebPage_CenterSelectionInVisibleArea = 1703
    , WebPage_GoToBackForwardItem = 1704
    , WebPage_TryRestoreScrollPosition = 1705
    , WebPage_LoadURLInFrame = 1706
    , WebPage_LoadDataInFrame = 1707
    , WebPage_LoadRequest = 1708
    , WebPage_LoadRequestWaitingForProcessLaunch = 1709
    , WebPage_LoadData = 1710
    , WebPage_LoadAlternateHTML = 1711
    , WebPage_NavigateToPDFLinkWithSimulatedClick = 1712
    , WebPage_Reload = 1713
    , WebPage_StopLoading = 1714
    , WebPage_StopLoadingFrame = 1715
    , WebPage_RestoreSession = 1716
    , WebPage_UpdateBackForwardListForReattach = 1717
    , WebPage_SetCurrentHistoryItemForReattach = 1718
    , WebPage_DidRemoveBackForwardItem = 1719
    , WebPage_UpdateWebsitePolicies = 1720
    , WebPage_NotifyUserScripts = 1721
    , WebPage_DidReceivePolicyDecision = 1722
    , WebPage_ContinueWillSubmitForm = 1723
    , WebPage_ClearSelection = 1724
    , WebPage_RestoreSelectionInFocusedEditableElement = 1725
    , WebPage_GetContentsAsString = 1726
    , WebPage_GetAllFrames = 1727
    , WebPage_GetAllFramesReply = 1728
#if PLATFORM(COCOA)
    , WebPage_GetContentsAsAttributedString = 1729
    , WebPage_GetContentsAsAttributedStringReply = 1730
#endif
#if ENABLE(MHTML)
    , WebPage_GetContentsAsMHTMLData = 1731
#endif
    , WebPage_GetMainResourceDataOfFrame = 1732
    , WebPage_GetResourceDataFromFrame = 1733
    , WebPage_GetRenderTreeExternalRepresentation = 1734
    , WebPage_GetSelectionOrContentsAsString = 1735
    , WebPage_GetSelectionAsWebArchiveData = 1736
    , WebPage_GetSourceForFrame = 1737
    , WebPage_GetWebArchiveOfFrame = 1738
    , WebPage_RunJavaScriptInFrameInScriptWorld = 1739
    , WebPage_ForceRepaint = 1740
    , WebPage_SelectAll = 1741
    , WebPage_ScheduleFullEditorStateUpdate = 1742
#if PLATFORM(COCOA)
    , WebPage_PerformDictionaryLookupOfCurrentSelection = 1743
#endif
#if PLATFORM(COCOA)
    , WebPage_PerformDictionaryLookupAtLocation = 1744
#endif
#if ENABLE(DATA_DETECTION)
    , WebPage_DetectDataInAllFrames = 1745
    , WebPage_DetectDataInAllFramesReply = 1746
#endif
#if ENABLE(DATA_DETECTION)
    , WebPage_RemoveDataDetectedLinks = 1747
    , WebPage_RemoveDataDetectedLinksReply = 1748
#endif
    , WebPage_ChangeFont = 1749
    , WebPage_ChangeFontAttributes = 1750
    , WebPage_PreferencesDidChange = 1751
    , WebPage_SetUserAgent = 1752
    , WebPage_SetCustomTextEncodingName = 1753
    , WebPage_SuspendActiveDOMObjectsAndAnimations = 1754
    , WebPage_ResumeActiveDOMObjectsAndAnimations = 1755
    , WebPage_Close = 1756
    , WebPage_TryClose = 1757
    , WebPage_TryCloseReply = 1758
    , WebPage_SetEditable = 1759
    , WebPage_ValidateCommand = 1760
    , WebPage_ExecuteEditCommand = 1761
    , WebPage_IncreaseListLevel = 1762
    , WebPage_DecreaseListLevel = 1763
    , WebPage_ChangeListType = 1764
    , WebPage_SetBaseWritingDirection = 1765
    , WebPage_SetNeedsFontAttributes = 1766
    , WebPage_RequestFontAttributesAtSelectionStart = 1767
    , WebPage_DidRemoveEditCommand = 1768
    , WebPage_ReapplyEditCommand = 1769
    , WebPage_UnapplyEditCommand = 1770
    , WebPage_SetPageAndTextZoomFactors = 1771
    , WebPage_SetPageZoomFactor = 1772
    , WebPage_SetTextZoomFactor = 1773
    , WebPage_WindowScreenDidChange = 1774
    , WebPage_AccessibilitySettingsDidChange = 1775
    , WebPage_ScalePage = 1776
    , WebPage_ScalePageInViewCoordinates = 1777
    , WebPage_ScaleView = 1778
    , WebPage_SetUseFixedLayout = 1779
    , WebPage_SetFixedLayoutSize = 1780
    , WebPage_ListenForLayoutMilestones = 1781
    , WebPage_SetSuppressScrollbarAnimations = 1782
    , WebPage_SetEnableVerticalRubberBanding = 1783
    , WebPage_SetEnableHorizontalRubberBanding = 1784
    , WebPage_SetBackgroundExtendsBeyondPage = 1785
    , WebPage_SetPaginationMode = 1786
    , WebPage_SetPaginationBehavesLikeColumns = 1787
    , WebPage_SetPageLength = 1788
    , WebPage_SetGapBetweenPages = 1789
    , WebPage_SetPaginationLineGridEnabled = 1790
    , WebPage_PostInjectedBundleMessage = 1791
    , WebPage_FindString = 1792
    , WebPage_FindStringMatches = 1793
    , WebPage_GetImageForFindMatch = 1794
    , WebPage_SelectFindMatch = 1795
    , WebPage_IndicateFindMatch = 1796
    , WebPage_HideFindUI = 1797
    , WebPage_CountStringMatches = 1798
    , WebPage_ReplaceMatches = 1799
    , WebPage_AddMIMETypeWithCustomContentProvider = 1800
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    , WebPage_PerformDragControllerAction = 1801
#endif
#if !PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    , WebPage_PerformDragControllerAction = 1802
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPage_DidStartDrag = 1803
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPage_DragEnded = 1804
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPage_DragCancelled = 1805
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    , WebPage_RequestDragStart = 1806
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    , WebPage_RequestAdditionalItemsForDragSession = 1807
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    , WebPage_InsertDroppedImagePlaceholders = 1808
    , WebPage_InsertDroppedImagePlaceholdersReply = 1809
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    , WebPage_DidConcludeDrop = 1810
#endif
    , WebPage_DidChangeSelectedIndexForActivePopupMenu = 1811
    , WebPage_SetTextForActivePopupMenu = 1812
#if PLATFORM(GTK)
    , WebPage_FailedToShowPopupMenu = 1813
#endif
#if ENABLE(CONTEXT_MENUS)
    , WebPage_DidSelectItemFromActiveContextMenu = 1814
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_DidChooseFilesForOpenPanelWithDisplayStringAndIcon = 1815
#endif
    , WebPage_DidChooseFilesForOpenPanel = 1816
    , WebPage_DidCancelForOpenPanel = 1817
#if ENABLE(SANDBOX_EXTENSIONS)
    , WebPage_ExtendSandboxForFilesFromOpenPanel = 1818
#endif
    , WebPage_AdvanceToNextMisspelling = 1819
    , WebPage_ChangeSpellingToWord = 1820
    , WebPage_DidFinishCheckingText = 1821
    , WebPage_DidCancelCheckingText = 1822
#if USE(APPKIT)
    , WebPage_UppercaseWord = 1823
#endif
#if USE(APPKIT)
    , WebPage_LowercaseWord = 1824
#endif
#if USE(APPKIT)
    , WebPage_CapitalizeWord = 1825
#endif
#if PLATFORM(COCOA)
    , WebPage_SetSmartInsertDeleteEnabled = 1826
#endif
#if ENABLE(GEOLOCATION)
    , WebPage_DidReceiveGeolocationPermissionDecision = 1827
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPage_UserMediaAccessWasGranted = 1828
    , WebPage_UserMediaAccessWasGrantedReply = 1829
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPage_UserMediaAccessWasDenied = 1830
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPage_CaptureDevicesChanged = 1831
#endif
    , WebPage_StopAllMediaPlayback = 1832
    , WebPage_SuspendAllMediaPlayback = 1833
    , WebPage_ResumeAllMediaPlayback = 1834
    , WebPage_DidReceiveNotificationPermissionDecision = 1835
    , WebPage_FreezeLayerTreeDueToSwipeAnimation = 1836
    , WebPage_UnfreezeLayerTreeDueToSwipeAnimation = 1837
    , WebPage_BeginPrinting = 1838
    , WebPage_EndPrinting = 1839
    , WebPage_ComputePagesForPrinting = 1840
#if PLATFORM(COCOA)
    , WebPage_DrawRectToImage = 1841
#endif
#if PLATFORM(COCOA)
    , WebPage_DrawPagesToPDF = 1842
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY))
    , WebPage_ComputePagesForPrintingAndDrawToPDF = 1843
#endif
#if PLATFORM(COCOA)
    , WebPage_DrawToPDF = 1844
#endif
#if PLATFORM(GTK)
    , WebPage_DrawPagesForPrinting = 1845
#endif
    , WebPage_SetMediaVolume = 1846
    , WebPage_SetMuted = 1847
    , WebPage_SetMayStartMediaWhenInWindow = 1848
    , WebPage_StopMediaCapture = 1849
#if ENABLE(MEDIA_SESSION)
    , WebPage_HandleMediaEvent = 1850
#endif
#if ENABLE(MEDIA_SESSION)
    , WebPage_SetVolumeOfMediaElement = 1851
#endif
    , WebPage_SetCanRunBeforeUnloadConfirmPanel = 1852
    , WebPage_SetCanRunModal = 1853
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPage_CancelComposition = 1854
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPage_DeleteSurrounding = 1855
#endif
#if PLATFORM(GTK)
    , WebPage_CollapseSelectionInFrame = 1856
#endif
#if PLATFORM(GTK)
    , WebPage_GetCenterForZoomGesture = 1857
#endif
#if PLATFORM(COCOA)
    , WebPage_SendComplexTextInputToPlugin = 1858
#endif
#if PLATFORM(COCOA)
    , WebPage_WindowAndViewFramesChanged = 1859
#endif
#if PLATFORM(COCOA)
    , WebPage_SetMainFrameIsScrollable = 1860
#endif
#if PLATFORM(COCOA)
    , WebPage_RegisterUIProcessAccessibilityTokens = 1861
#endif
#if PLATFORM(COCOA)
    , WebPage_GetStringSelectionForPasteboard = 1862
#endif
#if PLATFORM(COCOA)
    , WebPage_GetDataSelectionForPasteboard = 1863
#endif
#if PLATFORM(COCOA)
    , WebPage_ReadSelectionFromPasteboard = 1864
#endif
#if (PLATFORM(COCOA) && ENABLE(SERVICE_CONTROLS))
    , WebPage_ReplaceSelectionWithPasteboardData = 1865
#endif
#if PLATFORM(COCOA)
    , WebPage_ShouldDelayWindowOrderingEvent = 1866
#endif
#if PLATFORM(COCOA)
    , WebPage_AcceptsFirstMouse = 1867
#endif
#if PLATFORM(COCOA)
    , WebPage_SetTextAsync = 1868
#endif
#if PLATFORM(COCOA)
    , WebPage_InsertTextAsync = 1869
#endif
#if PLATFORM(COCOA)
    , WebPage_InsertDictatedTextAsync = 1870
#endif
#if PLATFORM(COCOA)
    , WebPage_HasMarkedText = 1871
    , WebPage_HasMarkedTextReply = 1872
#endif
#if PLATFORM(COCOA)
    , WebPage_GetMarkedRangeAsync = 1873
#endif
#if PLATFORM(COCOA)
    , WebPage_GetSelectedRangeAsync = 1874
#endif
#if PLATFORM(COCOA)
    , WebPage_CharacterIndexForPointAsync = 1875
#endif
#if PLATFORM(COCOA)
    , WebPage_FirstRectForCharacterRangeAsync = 1876
#endif
#if PLATFORM(COCOA)
    , WebPage_SetCompositionAsync = 1877
#endif
#if PLATFORM(COCOA)
    , WebPage_ConfirmCompositionAsync = 1878
#endif
#if PLATFORM(MAC)
    , WebPage_AttributedSubstringForCharacterRangeAsync = 1879
#endif
#if PLATFORM(MAC)
    , WebPage_FontAtSelection = 1880
#endif
    , WebPage_SetAlwaysShowsHorizontalScroller = 1881
    , WebPage_SetAlwaysShowsVerticalScroller = 1882
    , WebPage_SetMinimumSizeForAutoLayout = 1883
    , WebPage_SetSizeToContentAutoSizeMaximumSize = 1884
    , WebPage_SetAutoSizingShouldExpandToViewHeight = 1885
    , WebPage_SetViewportSizeForCSSViewportUnits = 1886
#if PLATFORM(COCOA)
    , WebPage_HandleAlternativeTextUIResult = 1887
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_WillStartUserTriggeredZooming = 1888
#endif
    , WebPage_SetScrollPinningBehavior = 1889
    , WebPage_SetScrollbarOverlayStyle = 1890
    , WebPage_GetBytecodeProfile = 1891
    , WebPage_GetSamplingProfilerOutput = 1892
    , WebPage_TakeSnapshot = 1893
#if PLATFORM(MAC)
    , WebPage_PerformImmediateActionHitTestAtLocation = 1894
#endif
#if PLATFORM(MAC)
    , WebPage_ImmediateActionDidUpdate = 1895
#endif
#if PLATFORM(MAC)
    , WebPage_ImmediateActionDidCancel = 1896
#endif
#if PLATFORM(MAC)
    , WebPage_ImmediateActionDidComplete = 1897
#endif
#if PLATFORM(MAC)
    , WebPage_DataDetectorsDidPresentUI = 1898
#endif
#if PLATFORM(MAC)
    , WebPage_DataDetectorsDidChangeUI = 1899
#endif
#if PLATFORM(MAC)
    , WebPage_DataDetectorsDidHideUI = 1900
#endif
#if PLATFORM(MAC)
    , WebPage_HandleAcceptedCandidate = 1901
#endif
#if PLATFORM(MAC)
    , WebPage_SetUseSystemAppearance = 1902
#endif
#if PLATFORM(MAC)
    , WebPage_SetHeaderBannerHeightForTesting = 1903
#endif
#if PLATFORM(MAC)
    , WebPage_SetFooterBannerHeightForTesting = 1904
#endif
#if PLATFORM(MAC)
    , WebPage_DidEndMagnificationGesture = 1905
#endif
    , WebPage_EffectiveAppearanceDidChange = 1906
#if PLATFORM(GTK)
    , WebPage_ThemeDidChange = 1907
#endif
#if PLATFORM(COCOA)
    , WebPage_RequestActiveNowPlayingSessionInfo = 1908
#endif
    , WebPage_SetShouldDispatchFakeMouseMoveEvents = 1909
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPage_PlaybackTargetSelected = 1910
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPage_PlaybackTargetAvailabilityDidChange = 1911
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPage_SetShouldPlayToPlaybackTarget = 1912
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPage_PlaybackTargetPickerWasDismissed = 1913
#endif
#if ENABLE(POINTER_LOCK)
    , WebPage_DidAcquirePointerLock = 1914
#endif
#if ENABLE(POINTER_LOCK)
    , WebPage_DidNotAcquirePointerLock = 1915
#endif
#if ENABLE(POINTER_LOCK)
    , WebPage_DidLosePointerLock = 1916
#endif
    , WebPage_clearWheelEventTestMonitor = 1917
    , WebPage_SetShouldScaleViewToFitDocument = 1918
#if ENABLE(VIDEO) && USE(GSTREAMER)
    , WebPage_DidEndRequestInstallMissingMediaPlugins = 1919
#endif
    , WebPage_SetUserInterfaceLayoutDirection = 1920
    , WebPage_DidGetLoadDecisionForIcon = 1921
    , WebPage_SetUseIconLoadingClient = 1922
#if ENABLE(GAMEPAD)
    , WebPage_GamepadActivity = 1923
#endif
    , WebPage_FrameBecameRemote = 1924
    , WebPage_RegisterURLSchemeHandler = 1925
    , WebPage_URLSchemeTaskDidPerformRedirection = 1926
    , WebPage_URLSchemeTaskDidReceiveResponse = 1927
    , WebPage_URLSchemeTaskDidReceiveData = 1928
    , WebPage_URLSchemeTaskDidComplete = 1929
    , WebPage_SetIsSuspended = 1930
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPage_InsertAttachment = 1931
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPage_UpdateAttachmentAttributes = 1932
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPage_UpdateAttachmentIcon = 1933
#endif
#if ENABLE(APPLICATION_MANIFEST)
    , WebPage_GetApplicationManifest = 1934
#endif
    , WebPage_SetDefersLoading = 1935
    , WebPage_UpdateCurrentModifierState = 1936
    , WebPage_SimulateDeviceOrientationChange = 1937
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPage_SpeakingErrorOccurred = 1938
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPage_BoundaryEventOccurred = 1939
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPage_VoicesDidChange = 1940
#endif
    , WebPage_SetCanShowPlaceholder = 1941
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebPage_WasLoadedWithDataTransferFromPrevalentResource = 1942
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebPage_ClearLoadedThirdPartyDomains = 1943
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebPage_LoadedThirdPartyDomains = 1944
    , WebPage_LoadedThirdPartyDomainsReply = 1945
#endif
#if USE(SYSTEM_PREVIEW)
    , WebPage_SystemPreviewActionTriggered = 1946
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPage_SendMessageToWebExtension = 1947
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPage_SendMessageToWebExtensionWithReply = 1948
    , WebPage_SendMessageToWebExtensionWithReplyReply = 1949
#endif
    , WebPage_StartTextManipulations = 1950
    , WebPage_StartTextManipulationsReply = 1951
    , WebPage_CompleteTextManipulation = 1952
    , WebPage_CompleteTextManipulationReply = 1953
    , WebPage_SetOverriddenMediaType = 1954
    , WebPage_GetProcessDisplayName = 1955
    , WebPage_GetProcessDisplayNameReply = 1956
    , WebPage_UpdateCORSDisablingPatterns = 1957
    , WebPage_SetShouldFireEvents = 1958
    , WebPage_SetNeedsDOMWindowResizeEvent = 1959
    , WebPage_SetHasResourceLoadClient = 1960
    , StorageAreaMap_DidSetItem = 1961
    , StorageAreaMap_DidRemoveItem = 1962
    , StorageAreaMap_DidClear = 1963
    , StorageAreaMap_DispatchStorageEvent = 1964
    , StorageAreaMap_ClearCache = 1965
#if PLATFORM(MAC)
    , ViewGestureController_DidCollectGeometryForMagnificationGesture = 1966
#endif
#if PLATFORM(MAC)
    , ViewGestureController_DidCollectGeometryForSmartMagnificationGesture = 1967
#endif
#if !PLATFORM(IOS_FAMILY)
    , ViewGestureController_DidHitRenderTreeSizeThreshold = 1968
#endif
#if PLATFORM(COCOA)
    , ViewGestureGeometryCollector_CollectGeometryForSmartMagnificationGesture = 1969
#endif
#if PLATFORM(MAC)
    , ViewGestureGeometryCollector_CollectGeometryForMagnificationGesture = 1970
#endif
#if !PLATFORM(IOS_FAMILY)
    , ViewGestureGeometryCollector_SetRenderTreeSizeNotificationThreshold = 1971
#endif
    , WrappedAsyncMessageForTesting = 1972
    , SyncMessageReply = 1973
    , InitializeConnection = 1974
    , LegacySessionState = 1975
};

ReceiverName receiverName(MessageName);
const char* description(MessageName);
bool isValidMessageName(MessageName);

} // namespace IPC

namespace WTF {

template<>
class HasCustomIsValidEnum<IPC::MessageName> : public std::true_type { };
template<typename E, typename T, typename = std::enable_if_t<std::is_same<E, IPC::MessageName>::value>>
bool isValidEnum(T messageName)
{
    static_assert(sizeof(T) == sizeof(IPC::MessageName), "isValidEnum<MessageName> should only be called with 16-bit types");
    return IPC::isValidMessageName(static_cast<IPC::MessageName>(messageName));
};

} // namespace WTF
