/*
 * Copyright (C) 2010-2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ArgumentCoders.h"
#include "Connection.h"
#include "MessageNames.h"
#include "WebInspectorMessagesReplies.h"
#include <WebCore/FrameIdentifier.h>
#include <wtf/Forward.h>
#include <wtf/ThreadSafeRefCounted.h>
#include <wtf/text/WTFString.h>

namespace IPC {
class Attachment;
}

namespace Messages {
namespace WebInspector {

static inline IPC::ReceiverName messageReceiverName()
{
    return IPC::ReceiverName::WebInspector;
}

class Show {
public:
    typedef std::tuple<> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_Show; }
    static const bool isSync = false;

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class Close {
public:
    typedef std::tuple<> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_Close; }
    static const bool isSync = false;

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class SetAttached {
public:
    typedef std::tuple<bool> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_SetAttached; }
    static const bool isSync = false;

    explicit SetAttached(bool attached)
        : m_arguments(attached)
    {
    }

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class ShowConsole {
public:
    typedef std::tuple<> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_ShowConsole; }
    static const bool isSync = false;

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class ShowResources {
public:
    typedef std::tuple<> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_ShowResources; }
    static const bool isSync = false;

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class ShowMainResourceForFrame {
public:
    typedef std::tuple<const WebCore::FrameIdentifier&> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_ShowMainResourceForFrame; }
    static const bool isSync = false;

    explicit ShowMainResourceForFrame(const WebCore::FrameIdentifier& frameIdentifier)
        : m_arguments(frameIdentifier)
    {
    }

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class OpenInNewTab {
public:
    typedef std::tuple<const String&> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_OpenInNewTab; }
    static const bool isSync = false;

    explicit OpenInNewTab(const String& url)
        : m_arguments(url)
    {
    }

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class StartPageProfiling {
public:
    typedef std::tuple<> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_StartPageProfiling; }
    static const bool isSync = false;

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class StopPageProfiling {
public:
    typedef std::tuple<> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_StopPageProfiling; }
    static const bool isSync = false;

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class StartElementSelection {
public:
    typedef std::tuple<> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_StartElementSelection; }
    static const bool isSync = false;

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class StopElementSelection {
public:
    typedef std::tuple<> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_StopElementSelection; }
    static const bool isSync = false;

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

class SetFrontendConnection {
public:
    typedef std::tuple<const IPC::Attachment&> Arguments;

    static IPC::MessageName name() { return IPC::MessageName::WebInspector_SetFrontendConnection; }
    static const bool isSync = false;

    explicit SetFrontendConnection(const IPC::Attachment& connectionIdentifier)
        : m_arguments(connectionIdentifier)
    {
    }

    const Arguments& arguments() const
    {
        return m_arguments;
    }

private:
    Arguments m_arguments;
};

} // namespace WebInspector
} // namespace Messages
